/*     */ package org.apache.batik.css.dom;
/*     */ 
/*     */ import java.util.HashMap;
/*     */ import java.util.Map;
/*     */ import org.apache.batik.css.engine.value.Value;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.css.CSSRule;
/*     */ import org.w3c.dom.css.CSSStyleDeclaration;
/*     */ import org.w3c.dom.css.CSSValue;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class CSSOMStyleDeclaration
/*     */   implements CSSStyleDeclaration
/*     */ {
/*     */   protected ValueProvider valueProvider;
/*     */   protected ModificationHandler handler;
/*     */   protected CSSRule parentRule;
/*     */   protected Map values;
/*     */   
/*     */   public CSSOMStyleDeclaration(ValueProvider vp, CSSRule parent) {
/*  62 */     this.valueProvider = vp;
/*  63 */     this.parentRule = parent;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  70 */   public void setModificationHandler(ModificationHandler h) { this.handler = h; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  78 */   public String getCssText() { return this.valueProvider.getText(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setCssText(String cssText) throws DOMException {
/*  86 */     if (this.handler == null) {
/*  87 */       throw new DOMException((short)7, "");
/*     */     }
/*     */     
/*  90 */     this.values = null;
/*  91 */     this.handler.textChanged(cssText);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getPropertyValue(String propertyName) {
/* 100 */     Value value = this.valueProvider.getValue(propertyName);
/* 101 */     if (value == null) {
/* 102 */       return "";
/*     */     }
/* 104 */     return value.getCssText();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSValue getPropertyCSSValue(String propertyName) {
/* 112 */     Value value = this.valueProvider.getValue(propertyName);
/* 113 */     if (value == null) {
/* 114 */       return null;
/*     */     }
/* 116 */     return getCSSValue(propertyName);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String removeProperty(String propertyName) {
/* 124 */     String result = getPropertyValue(propertyName);
/* 125 */     if (result.length() > 0) {
/* 126 */       if (this.handler == null) {
/* 127 */         throw new DOMException((short)7, "");
/*     */       }
/*     */       
/* 130 */       if (this.values != null) {
/* 131 */         this.values.remove(propertyName);
/*     */       }
/* 133 */       this.handler.propertyRemoved(propertyName);
/*     */     } 
/*     */     
/* 136 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 144 */   public String getPropertyPriority(String propertyName) { return this.valueProvider.isImportant(propertyName) ? "important" : ""; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setProperty(String propertyName, String value, String prio) throws DOMException {
/* 153 */     if (this.handler == null) {
/* 154 */       throw new DOMException((short)7, "");
/*     */     }
/*     */     
/* 157 */     this.handler.propertyChanged(propertyName, value, prio);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 166 */   public int getLength() { return this.valueProvider.getLength(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 174 */   public String item(int index) { return this.valueProvider.item(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 182 */   public CSSRule getParentRule() { return this.parentRule; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected CSSValue getCSSValue(String name) {
/* 189 */     CSSValue result = null;
/* 190 */     if (this.values != null) {
/* 191 */       result = (CSSValue)this.values.get(name);
/*     */     }
/* 193 */     if (result == null) {
/* 194 */       result = createCSSValue(name);
/* 195 */       if (this.values == null) {
/* 196 */         this.values = new HashMap(11);
/*     */       }
/* 198 */       this.values.put(name, result);
/*     */     } 
/* 200 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 207 */   protected CSSValue createCSSValue(String name) { return new StyleDeclarationValue(this, name); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class StyleDeclarationValue
/*     */     extends CSSOMValue
/*     */     implements CSSOMValue.ValueProvider
/*     */   {
/*     */     protected String property;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private final CSSOMStyleDeclaration this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public StyleDeclarationValue(CSSOMStyleDeclaration this$0, String prop) {
/* 279 */       super(null); this.this$0 = this$0;
/* 280 */       this.valueProvider = this;
/* 281 */       setModificationHandler(new CSSOMStyleDeclaration$1(this));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 298 */       this.property = prop;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 307 */     public Value getValue() { return this.this$0.valueProvider.getValue(this.property); }
/*     */   }
/*     */   
/*     */   public static interface ModificationHandler {
/*     */     void textChanged(String param1String) throws DOMException;
/*     */     
/*     */     void propertyRemoved(String param1String) throws DOMException;
/*     */     
/*     */     void propertyChanged(String param1String1, String param1String2, String param1String3) throws DOMException;
/*     */   }
/*     */   
/*     */   public static interface ValueProvider {
/*     */     Value getValue(String param1String);
/*     */     
/*     */     boolean isImportant(String param1String);
/*     */     
/*     */     String getText();
/*     */     
/*     */     int getLength();
/*     */     
/*     */     String item(int param1Int);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\dom\CSSOMStyleDeclaration.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */