/*      */ package org.apache.batik.css.engine;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.StringReader;
/*      */ import java.util.ArrayList;
/*      */ import java.util.Collections;
/*      */ import java.util.HashSet;
/*      */ import java.util.LinkedList;
/*      */ import java.util.List;
/*      */ import java.util.Set;
/*      */ import org.apache.batik.css.engine.sac.CSSConditionFactory;
/*      */ import org.apache.batik.css.engine.sac.CSSSelectorFactory;
/*      */ import org.apache.batik.css.engine.sac.ExtendedSelector;
/*      */ import org.apache.batik.css.engine.value.ComputedValue;
/*      */ import org.apache.batik.css.engine.value.InheritValue;
/*      */ import org.apache.batik.css.engine.value.ShorthandManager;
/*      */ import org.apache.batik.css.engine.value.Value;
/*      */ import org.apache.batik.css.engine.value.ValueManager;
/*      */ import org.apache.batik.css.parser.ExtendedParser;
/*      */ import org.apache.batik.util.ParsedURL;
/*      */ import org.jd.gui.api.API;
/*      */ import org.w3c.css.sac.CSSException;
/*      */ import org.w3c.css.sac.DocumentHandler;
/*      */ import org.w3c.css.sac.InputSource;
/*      */ import org.w3c.css.sac.LexicalUnit;
/*      */ import org.w3c.css.sac.SACMediaList;
/*      */ import org.w3c.css.sac.SelectorList;
/*      */ import org.w3c.dom.Attr;
/*      */ import org.w3c.dom.DOMException;
/*      */ import org.w3c.dom.Document;
/*      */ import org.w3c.dom.Element;
/*      */ import org.w3c.dom.NamedNodeMap;
/*      */ import org.w3c.dom.Node;
/*      */ import org.w3c.dom.events.Event;
/*      */ import org.w3c.dom.events.EventListener;
/*      */ import org.w3c.dom.events.EventTarget;
/*      */ import org.w3c.dom.events.MutationEvent;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class CSSEngine
/*      */ {
/*      */   protected CSSEngineUserAgent userAgent;
/*      */   protected CSSContext cssContext;
/*      */   protected Document document;
/*      */   protected ParsedURL documentURI;
/*      */   protected boolean isCSSNavigableDocument;
/*      */   protected StringIntMap indexes;
/*      */   protected StringIntMap shorthandIndexes;
/*      */   protected ValueManager[] valueManagers;
/*      */   protected ShorthandManager[] shorthandManagers;
/*      */   protected ExtendedParser parser;
/*      */   protected String[] pseudoElementNames;
/*      */   protected int fontSizeIndex;
/*      */   protected int lineHeightIndex;
/*      */   protected int colorIndex;
/*      */   protected StyleSheet userAgentStyleSheet;
/*      */   protected StyleSheet userStyleSheet;
/*      */   protected SACMediaList media;
/*      */   protected List styleSheetNodes;
/*      */   protected List fontFaces;
/*      */   protected String styleNamespaceURI;
/*      */   protected String styleLocalName;
/*      */   protected String classNamespaceURI;
/*      */   
/*      */   public static Node getCSSParentNode(Node n) {
/*   71 */     if (n instanceof CSSNavigableNode) {
/*   72 */       return ((CSSNavigableNode)n).getCSSParentNode();
/*      */     }
/*   74 */     return n.getParentNode();
/*      */   }
/*      */   protected String classLocalName; protected Set nonCSSPresentationalHints; protected String nonCSSPresentationalHintsNamespaceURI; protected StyleDeclarationDocumentHandler styleDeclarationDocumentHandler; protected StyleDeclarationUpdateHandler styleDeclarationUpdateHandler; protected StyleSheetDocumentHandler styleSheetDocumentHandler; protected StyleDeclarationBuilder styleDeclarationBuilder; protected CSSStylableElement element; protected ParsedURL cssBaseURI; protected String alternateStyleSheet; protected CSSNavigableDocumentHandler cssNavigableDocumentListener; protected EventListener domAttrModifiedListener; protected EventListener domNodeInsertedListener; protected EventListener domNodeRemovedListener; protected EventListener domSubtreeModifiedListener; protected EventListener domCharacterDataModifiedListener; protected boolean styleSheetRemoved; protected Node removedStylableElementSibling; protected List listeners; protected Set selectorAttributes;
/*      */   protected final int[] ALL_PROPERTIES;
/*      */   protected CSSConditionFactory cssConditionFactory;
/*      */   
/*      */   protected static Node getCSSFirstChild(Node n) {
/*   81 */     if (n instanceof CSSNavigableNode) {
/*   82 */       return ((CSSNavigableNode)n).getCSSFirstChild();
/*      */     }
/*   84 */     return n.getFirstChild();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static Node getCSSNextSibling(Node n) {
/*   91 */     if (n instanceof CSSNavigableNode) {
/*   92 */       return ((CSSNavigableNode)n).getCSSNextSibling();
/*      */     }
/*   94 */     return n.getNextSibling();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static Node getCSSPreviousSibling(Node n) {
/*  101 */     if (n instanceof CSSNavigableNode) {
/*  102 */       return ((CSSNavigableNode)n).getCSSPreviousSibling();
/*      */     }
/*  104 */     return n.getPreviousSibling();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static CSSStylableElement getParentCSSStylableElement(Element elt) {
/*  111 */     Node n = getCSSParentNode(elt);
/*  112 */     while (n != null) {
/*  113 */       if (n instanceof CSSStylableElement) {
/*  114 */         return (CSSStylableElement)n;
/*      */       }
/*  116 */       n = getCSSParentNode(n);
/*      */     } 
/*  118 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected CSSEngine(Document doc, ParsedURL uri, ExtendedParser p, ValueManager[] vm, ShorthandManager[] sm, String[] pe, String sns, String sln, String cns, String cln, boolean hints, String hintsNS, CSSContext ctx) {
/*  179 */     this.fontSizeIndex = -1;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  184 */     this.lineHeightIndex = -1;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  189 */     this.colorIndex = -1;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  215 */     this.fontFaces = new LinkedList();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  250 */     this.styleDeclarationDocumentHandler = new StyleDeclarationDocumentHandler(this);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  261 */     this.styleSheetDocumentHandler = new StyleSheetDocumentHandler(this);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  268 */     this.styleDeclarationBuilder = new StyleDeclarationBuilder(this);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  329 */     this.listeners = Collections.synchronizedList(new LinkedList());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  378 */     this.document = doc;
/*  379 */     this.documentURI = uri;
/*  380 */     this.parser = p;
/*  381 */     this.pseudoElementNames = pe;
/*  382 */     this.styleNamespaceURI = sns;
/*  383 */     this.styleLocalName = sln;
/*  384 */     this.classNamespaceURI = cns;
/*  385 */     this.classLocalName = cln;
/*  386 */     this.cssContext = ctx;
/*      */     
/*  388 */     this.isCSSNavigableDocument = doc instanceof CSSNavigableDocument;
/*      */     
/*  390 */     this.cssConditionFactory = new CSSConditionFactory(cns, cln, null, "id");
/*      */     
/*  392 */     int len = vm.length;
/*  393 */     this.indexes = new StringIntMap(len);
/*  394 */     this.valueManagers = vm;
/*      */     
/*  396 */     for (int i = len - 1; i >= 0; i--) {
/*  397 */       String pn = vm[i].getPropertyName();
/*  398 */       this.indexes.put(pn, i);
/*  399 */       if (this.fontSizeIndex == -1 && pn.equals("font-size"))
/*      */       {
/*  401 */         this.fontSizeIndex = i;
/*      */       }
/*  403 */       if (this.lineHeightIndex == -1 && pn.equals("line-height"))
/*      */       {
/*  405 */         this.lineHeightIndex = i;
/*      */       }
/*  407 */       if (this.colorIndex == -1 && pn.equals("color"))
/*      */       {
/*  409 */         this.colorIndex = i;
/*      */       }
/*      */     } 
/*      */     
/*  413 */     len = sm.length;
/*  414 */     this.shorthandIndexes = new StringIntMap(len);
/*  415 */     this.shorthandManagers = sm;
/*  416 */     for (int i = len - 1; i >= 0; i--) {
/*  417 */       this.shorthandIndexes.put(sm[i].getPropertyName(), i);
/*      */     }
/*      */     
/*  420 */     if (hints) {
/*  421 */       this.nonCSSPresentationalHints = new HashSet(vm.length + sm.length);
/*  422 */       this.nonCSSPresentationalHintsNamespaceURI = hintsNS;
/*  423 */       len = vm.length;
/*  424 */       for (int i = 0; i < len; i++) {
/*  425 */         String pn = vm[i].getPropertyName();
/*  426 */         this.nonCSSPresentationalHints.add(pn);
/*      */       } 
/*  428 */       len = sm.length;
/*  429 */       for (int i = 0; i < len; i++) {
/*  430 */         String pn = sm[i].getPropertyName();
/*  431 */         this.nonCSSPresentationalHints.add(pn);
/*      */       } 
/*      */     } 
/*      */     
/*  435 */     if (this.cssContext.isDynamic() && this.document instanceof EventTarget) {
/*      */       
/*  437 */       addEventListeners((EventTarget)this.document);
/*  438 */       this.styleDeclarationUpdateHandler = new StyleDeclarationUpdateHandler(this);
/*      */     } 
/*      */ 
/*      */     
/*  442 */     this.ALL_PROPERTIES = new int[getNumberOfProperties()];
/*  443 */     for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/*  444 */       this.ALL_PROPERTIES[i] = i;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void addEventListeners(EventTarget doc) {
/*  452 */     if (this.isCSSNavigableDocument) {
/*  453 */       this.cssNavigableDocumentListener = new CSSNavigableDocumentHandler(this);
/*  454 */       CSSNavigableDocument cnd = (CSSNavigableDocument)doc;
/*  455 */       cnd.addCSSNavigableDocumentListener(this.cssNavigableDocumentListener);
/*      */     } else {
/*  457 */       this.domAttrModifiedListener = new DOMAttrModifiedListener(this);
/*  458 */       doc.addEventListener("DOMAttrModified", this.domAttrModifiedListener, false);
/*      */ 
/*      */       
/*  461 */       this.domNodeInsertedListener = new DOMNodeInsertedListener(this);
/*  462 */       doc.addEventListener("DOMNodeInserted", this.domNodeInsertedListener, false);
/*      */ 
/*      */       
/*  465 */       this.domNodeRemovedListener = new DOMNodeRemovedListener(this);
/*  466 */       doc.addEventListener("DOMNodeRemoved", this.domNodeRemovedListener, false);
/*      */ 
/*      */       
/*  469 */       this.domSubtreeModifiedListener = new DOMSubtreeModifiedListener(this);
/*  470 */       doc.addEventListener("DOMSubtreeModified", this.domSubtreeModifiedListener, false);
/*      */ 
/*      */       
/*  473 */       this.domCharacterDataModifiedListener = new DOMCharacterDataModifiedListener(this);
/*      */       
/*  475 */       doc.addEventListener("DOMCharacterDataModified", this.domCharacterDataModifiedListener, false);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void removeEventListeners(EventTarget doc) {
/*  485 */     if (this.isCSSNavigableDocument) {
/*  486 */       CSSNavigableDocument cnd = (CSSNavigableDocument)doc;
/*  487 */       cnd.removeCSSNavigableDocumentListener(this.cssNavigableDocumentListener);
/*      */     } else {
/*      */       
/*  490 */       doc.removeEventListener("DOMAttrModified", this.domAttrModifiedListener, false);
/*      */ 
/*      */       
/*  493 */       doc.removeEventListener("DOMNodeInserted", this.domNodeInsertedListener, false);
/*      */ 
/*      */       
/*  496 */       doc.removeEventListener("DOMNodeRemoved", this.domNodeRemovedListener, false);
/*      */ 
/*      */       
/*  499 */       doc.removeEventListener("DOMSubtreeModified", this.domSubtreeModifiedListener, false);
/*      */ 
/*      */       
/*  502 */       doc.removeEventListener("DOMCharacterDataModified", this.domCharacterDataModifiedListener, false);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void dispose() {
/*  512 */     setCSSEngineUserAgent(null);
/*  513 */     disposeStyleMaps(this.document.getDocumentElement());
/*  514 */     if (this.document instanceof EventTarget)
/*      */     {
/*  516 */       removeEventListeners((EventTarget)this.document);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void disposeStyleMaps(Node node) {
/*  524 */     if (node instanceof CSSStylableElement) {
/*  525 */       ((CSSStylableElement)node).setComputedStyleMap(null, null);
/*      */     }
/*  527 */     Node n = getCSSFirstChild(node);
/*  528 */     for (; n != null; 
/*  529 */       n = getCSSNextSibling(n)) {
/*  530 */       if (n.getNodeType() == 1) {
/*  531 */         disposeStyleMaps(n);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  540 */   public CSSContext getCSSContext() { return this.cssContext; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  547 */   public Document getDocument() { return this.document; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  554 */   public int getFontSizeIndex() { return this.fontSizeIndex; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  561 */   public int getLineHeightIndex() { return this.lineHeightIndex; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  568 */   public int getColorIndex() { return this.colorIndex; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  575 */   public int getNumberOfProperties() { return this.valueManagers.length; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  582 */   public int getPropertyIndex(String name) { return this.indexes.get(name); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  589 */   public int getShorthandIndex(String name) { return this.shorthandIndexes.get(name); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  596 */   public String getPropertyName(int idx) { return this.valueManagers[idx].getPropertyName(); }
/*      */ 
/*      */ 
/*      */   
/*  600 */   public void setCSSEngineUserAgent(CSSEngineUserAgent userAgent) { this.userAgent = userAgent; }
/*      */ 
/*      */ 
/*      */   
/*  604 */   public CSSEngineUserAgent getCSSEngineUserAgent() { return this.userAgent; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  611 */   public void setUserAgentStyleSheet(StyleSheet ss) { this.userAgentStyleSheet = ss; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  618 */   public void setUserStyleSheet(StyleSheet ss) { this.userStyleSheet = ss; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  625 */   public ValueManager[] getValueManagers() { return this.valueManagers; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  632 */   public ShorthandManager[] getShorthandManagers() { return this.shorthandManagers; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  640 */   public List getFontFaces() { return this.fontFaces; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setMedia(String str) {
/*      */     try {
/*  648 */       this.media = this.parser.parseMedia(str);
/*      */     } catch (Exception e) {
/*  650 */       String m = e.getMessage();
/*  651 */       if (m == null) m = ""; 
/*  652 */       String s = Messages.formatMessage("media.error", new Object[] { str, m });
/*      */       
/*  654 */       throw new DOMException((short)12, s);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  662 */   public void setAlternateStyleSheet(String str) { this.alternateStyleSheet = str; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void importCascadedStyleMaps(Element src, CSSEngine srceng, Element dest) {
/*  672 */     if (src instanceof CSSStylableElement) {
/*  673 */       CSSStylableElement csrc = (CSSStylableElement)src;
/*  674 */       CSSStylableElement cdest = (CSSStylableElement)dest;
/*      */       
/*  676 */       StyleMap sm = srceng.getCascadedStyleMap(csrc, null);
/*  677 */       sm.setFixedCascadedStyle(true);
/*  678 */       cdest.setComputedStyleMap(null, sm);
/*      */       
/*  680 */       if (this.pseudoElementNames != null) {
/*  681 */         int len = this.pseudoElementNames.length;
/*  682 */         for (int i = 0; i < len; i++) {
/*  683 */           String pe = this.pseudoElementNames[i];
/*  684 */           sm = srceng.getCascadedStyleMap(csrc, pe);
/*  685 */           cdest.setComputedStyleMap(pe, sm);
/*      */         } 
/*      */       } 
/*      */     } 
/*      */     
/*  690 */     Node dn = getCSSFirstChild(dest), sn = getCSSFirstChild(src);
/*  691 */     for (; dn != null; 
/*  692 */       dn = getCSSNextSibling(dn), sn = getCSSNextSibling(sn)) {
/*  693 */       if (sn.getNodeType() == 1) {
/*  694 */         importCascadedStyleMaps((Element)sn, srceng, (Element)dn);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public ParsedURL getCSSBaseURI() {
/*  703 */     if (this.cssBaseURI == null) {
/*  704 */       this.cssBaseURI = this.element.getCSSBase();
/*      */     }
/*  706 */     return this.cssBaseURI;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public StyleMap getCascadedStyleMap(CSSStylableElement elt, String pseudo) {
/*  716 */     int props = getNumberOfProperties();
/*  717 */     StyleMap result = new StyleMap(props);
/*      */ 
/*      */     
/*  720 */     if (this.userAgentStyleSheet != null) {
/*  721 */       ArrayList rules = new ArrayList();
/*  722 */       addMatchingRules(rules, this.userAgentStyleSheet, elt, pseudo);
/*  723 */       addRules(elt, pseudo, result, rules, (short)0);
/*      */     } 
/*      */ 
/*      */     
/*  727 */     if (this.userStyleSheet != null) {
/*  728 */       ArrayList rules = new ArrayList();
/*  729 */       addMatchingRules(rules, this.userStyleSheet, elt, pseudo);
/*  730 */       addRules(elt, pseudo, result, rules, (short)8192);
/*      */     } 
/*      */     
/*  733 */     this.element = elt;
/*      */     
/*      */     try {
/*  736 */       if (this.nonCSSPresentationalHints != null) {
/*  737 */         ShorthandManager.PropertyHandler ph = new ShorthandManager.PropertyHandler(this, result) { private final StyleMap val$result;
/*      */             private final CSSEngine this$0;
/*      */             
/*      */             public void property(String pname, LexicalUnit lu, boolean important) throws CSSException {
/*  741 */               int idx = this.this$0.getPropertyIndex(pname);
/*  742 */               if (idx != -1) {
/*  743 */                 ValueManager vm = this.this$0.valueManagers[idx];
/*  744 */                 Value v = vm.createValue(lu, this.this$0);
/*  745 */                 this.this$0.putAuthorProperty(this.val$result, idx, v, important, (short)16384);
/*      */                 
/*      */                 return;
/*      */               } 
/*  749 */               idx = this.this$0.getShorthandIndex(pname);
/*  750 */               if (idx == -1) {
/*      */                 return;
/*      */               }
/*  753 */               this.this$0.shorthandManagers[idx].setValues(this.this$0, this, lu, important);
/*      */             } }
/*      */           ;
/*      */ 
/*      */         
/*  758 */         NamedNodeMap attrs = elt.getAttributes();
/*  759 */         int len = attrs.getLength();
/*  760 */         for (int i = 0; i < len; i++) {
/*  761 */           Node attr = attrs.item(i);
/*  762 */           String an = attr.getNodeName();
/*  763 */           if (this.nonCSSPresentationalHints.contains(an)) {
/*  764 */             String attrValue = attr.getNodeValue();
/*      */             
/*      */             try {
/*  767 */               LexicalUnit lu = this.parser.parsePropertyValue(attr.getNodeValue());
/*  768 */               ph.property(an, lu, false);
/*      */             } catch (Exception e) {
/*      */               
/*  771 */               System.err.println("\n***** CSSEngine: exception property.syntax.error:" + e);
/*  772 */               System.err.println("\nAttrValue:" + attrValue);
/*  773 */               System.err.println("\nException:" + e.getClass().getName());
/*  774 */               e.printStackTrace(System.err);
/*  775 */               System.err.println("\n***** CSSEngine: exception....");
/*      */               
/*  777 */               String m = e.getMessage();
/*  778 */               if (m == null) m = ""; 
/*  779 */               String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */               
/*  781 */               String s = Messages.formatMessage("property.syntax.error.at", new Object[] { u, an, attr.getNodeValue(), m });
/*      */ 
/*      */               
/*  784 */               DOMException de = new DOMException((short)12, s);
/*  785 */               if (this.userAgent == null) throw de; 
/*  786 */               this.userAgent.displayError(de);
/*      */             } 
/*      */           } 
/*      */         } 
/*      */       } 
/*      */ 
/*      */       
/*  793 */       CSSEngine eng = this.cssContext.getCSSEngineForElement(elt);
/*  794 */       List snodes = eng.getStyleSheetNodes();
/*  795 */       int slen = snodes.size();
/*  796 */       if (slen > 0) {
/*  797 */         ArrayList rules = new ArrayList();
/*  798 */         for (int i = 0; i < slen; i++) {
/*  799 */           CSSStyleSheetNode ssn = (CSSStyleSheetNode)snodes.get(i);
/*  800 */           StyleSheet ss = ssn.getCSSStyleSheet();
/*  801 */           if (ss != null && (!ss.isAlternate() || ss.getTitle() == null || ss.getTitle().equals(this.alternateStyleSheet)) && mediaMatch(ss.getMedia()))
/*      */           {
/*      */ 
/*      */ 
/*      */             
/*  806 */             addMatchingRules(rules, ss, elt, pseudo);
/*      */           }
/*      */         } 
/*  809 */         addRules(elt, pseudo, result, rules, (short)24576);
/*      */       } 
/*      */ 
/*      */       
/*  813 */       if (this.styleLocalName != null) {
/*  814 */         String style = elt.getAttributeNS(this.styleNamespaceURI, this.styleLocalName);
/*      */         
/*  816 */         if (style.length() > 0) {
/*      */           try {
/*  818 */             this.parser.setSelectorFactory(CSSSelectorFactory.INSTANCE);
/*  819 */             this.parser.setConditionFactory(this.cssConditionFactory);
/*  820 */             this.styleDeclarationDocumentHandler.styleMap = result;
/*  821 */             this.parser.setDocumentHandler(this.styleDeclarationDocumentHandler);
/*      */             
/*  823 */             this.parser.parseStyleDeclaration(style);
/*  824 */             this.styleDeclarationDocumentHandler.styleMap = null;
/*      */           } catch (Exception e) {
/*  826 */             String m = e.getMessage();
/*  827 */             if (m == null) m = e.getClass().getName(); 
/*  828 */             String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */             
/*  830 */             String s = Messages.formatMessage("style.syntax.error.at", new Object[] { u, this.styleLocalName, style, m });
/*      */ 
/*      */             
/*  833 */             DOMException de = new DOMException((short)12, s);
/*  834 */             if (this.userAgent == null) throw de; 
/*  835 */             this.userAgent.displayError(de);
/*      */           } 
/*      */         }
/*      */       } 
/*      */ 
/*      */       
/*  841 */       StyleDeclarationProvider p = elt.getOverrideStyleDeclarationProvider();
/*      */       
/*  843 */       if (p != null) {
/*  844 */         StyleDeclaration over = p.getStyleDeclaration();
/*  845 */         if (over != null) {
/*  846 */           int ol = over.size();
/*  847 */           for (int i = 0; i < ol; i++) {
/*  848 */             int idx = over.getIndex(i);
/*  849 */             Value value = over.getValue(i);
/*  850 */             boolean important = over.getPriority(i);
/*  851 */             if (!result.isImportant(idx) || important) {
/*  852 */               result.putValue(idx, value);
/*  853 */               result.putImportant(idx, important);
/*  854 */               result.putOrigin(idx, (short)-24576);
/*      */             } 
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     } finally {
/*  860 */       this.element = null;
/*  861 */       this.cssBaseURI = null;
/*      */     } 
/*      */     
/*  864 */     return result;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Value getComputedStyle(CSSStylableElement elt, String pseudo, int propidx) {
/*  874 */     StyleMap sm = elt.getComputedStyleMap(pseudo);
/*  875 */     if (sm == null) {
/*  876 */       sm = getCascadedStyleMap(elt, pseudo);
/*  877 */       elt.setComputedStyleMap(pseudo, sm);
/*      */     } 
/*      */     
/*  880 */     Value value = sm.getValue(propidx);
/*  881 */     if (sm.isComputed(propidx)) {
/*  882 */       return value;
/*      */     }
/*  884 */     ComputedValue computedValue = value;
/*  885 */     ValueManager vm = this.valueManagers[propidx];
/*  886 */     CSSStylableElement p = getParentCSSStylableElement(elt);
/*  887 */     if (value == null) {
/*  888 */       if (p == null || !vm.isInheritedProperty())
/*  889 */         computedValue = vm.getDefaultValue(); 
/*  890 */     } else if (p != null && value == InheritValue.INSTANCE) {
/*  891 */       computedValue = null;
/*      */     } 
/*  893 */     if (computedValue == null) {
/*      */ 
/*      */       
/*  896 */       computedValue = getComputedStyle(p, null, propidx);
/*  897 */       sm.putParentRelative(propidx, true);
/*  898 */       sm.putInherited(propidx, true);
/*      */     } else {
/*      */       
/*  901 */       computedValue = vm.computeValue(elt, pseudo, this, propidx, sm, computedValue);
/*      */     } 
/*      */     
/*  904 */     if (value == null) {
/*  905 */       sm.putValue(propidx, computedValue);
/*  906 */       sm.putNullCascaded(propidx, true);
/*  907 */     } else if (computedValue != value) {
/*  908 */       ComputedValue cv = new ComputedValue(value);
/*  909 */       cv.setComputedValue(computedValue);
/*  910 */       sm.putValue(propidx, cv);
/*  911 */       computedValue = cv;
/*      */     } 
/*      */     
/*  914 */     sm.putComputed(propidx, true);
/*  915 */     return computedValue;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public List getStyleSheetNodes() {
/*  923 */     if (this.styleSheetNodes == null) {
/*  924 */       this.styleSheetNodes = new ArrayList();
/*  925 */       this.selectorAttributes = new HashSet();
/*      */       
/*  927 */       findStyleSheetNodes(this.document);
/*  928 */       int len = this.styleSheetNodes.size();
/*  929 */       for (int i = 0; i < len; i++) {
/*      */         
/*  931 */         CSSStyleSheetNode ssn = (CSSStyleSheetNode)this.styleSheetNodes.get(i);
/*  932 */         StyleSheet ss = ssn.getCSSStyleSheet();
/*  933 */         if (ss != null) {
/*  934 */           findSelectorAttributes(this.selectorAttributes, ss);
/*      */         }
/*      */       } 
/*      */     } 
/*  938 */     return this.styleSheetNodes;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void findStyleSheetNodes(Node n) {
/*  945 */     if (n instanceof CSSStyleSheetNode) {
/*  946 */       this.styleSheetNodes.add(n);
/*      */     }
/*  948 */     Node nd = getCSSFirstChild(n);
/*  949 */     for (; nd != null; 
/*  950 */       nd = getCSSNextSibling(nd)) {
/*  951 */       findStyleSheetNodes(nd);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void findSelectorAttributes(Set attrs, StyleSheet ss) {
/*  959 */     int len = ss.getSize();
/*  960 */     for (int i = 0; i < len; i++) {
/*  961 */       MediaRule mr; int j, slen; SelectorList sl; StyleRule style; Rule r = ss.getRule(i);
/*  962 */       switch (r.getType()) {
/*      */         case 0:
/*  964 */           style = (StyleRule)r;
/*  965 */           sl = style.getSelectorList();
/*  966 */           slen = sl.getLength();
/*  967 */           for (j = 0; j < slen; j++) {
/*  968 */             ExtendedSelector s = (ExtendedSelector)sl.item(j);
/*  969 */             s.fillAttributeSet(attrs);
/*      */           } 
/*      */           break;
/*      */         
/*      */         case 1:
/*      */         case 2:
/*  975 */           mr = (MediaRule)r;
/*  976 */           if (mediaMatch(mr.getMediaList())) {
/*  977 */             findSelectorAttributes(attrs, mr);
/*      */           }
/*      */           break;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setMainProperties(CSSStylableElement elt, MainPropertyReceiver dst, String pname, String value, boolean important) {
/*      */     try {
/* 1000 */       this.element = elt;
/* 1001 */       LexicalUnit lu = this.parser.parsePropertyValue(value);
/* 1002 */       ShorthandManager.PropertyHandler ph = new ShorthandManager.PropertyHandler(this, dst) { private final CSSEngine.MainPropertyReceiver val$dst;
/*      */           private final CSSEngine this$0;
/*      */           
/*      */           public void property(String pname, LexicalUnit lu, boolean important) throws CSSException {
/* 1006 */             int idx = this.this$0.getPropertyIndex(pname);
/* 1007 */             if (idx != -1) {
/* 1008 */               ValueManager vm = this.this$0.valueManagers[idx];
/* 1009 */               Value v = vm.createValue(lu, this.this$0);
/* 1010 */               this.val$dst.setMainProperty(pname, v, important);
/*      */               return;
/*      */             } 
/* 1013 */             idx = this.this$0.getShorthandIndex(pname);
/* 1014 */             if (idx == -1) {
/*      */               return;
/*      */             }
/* 1017 */             this.this$0.shorthandManagers[idx].setValues(this.this$0, this, lu, important);
/*      */           } }
/*      */         ;
/*      */       
/* 1021 */       ph.property(pname, lu, important);
/*      */     } catch (Exception e) {
/* 1023 */       String m = e.getMessage();
/* 1024 */       if (m == null) m = ""; 
/* 1025 */       String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */       
/* 1027 */       String s = Messages.formatMessage("property.syntax.error.at", new Object[] { u, pname, value, m });
/*      */ 
/*      */       
/* 1030 */       DOMException de = new DOMException((short)12, s);
/* 1031 */       if (this.userAgent == null) throw de; 
/* 1032 */       this.userAgent.displayError(de);
/*      */     } finally {
/* 1034 */       this.element = null;
/* 1035 */       this.cssBaseURI = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Value parsePropertyValue(CSSStylableElement elt, String prop, String value) {
/* 1047 */     int idx = getPropertyIndex(prop);
/* 1048 */     if (idx == -1) return null; 
/* 1049 */     ValueManager vm = this.valueManagers[idx];
/*      */     try {
/* 1051 */       this.element = elt;
/*      */       
/* 1053 */       LexicalUnit lu = this.parser.parsePropertyValue(value);
/* 1054 */       return vm.createValue(lu, this);
/*      */     } catch (Exception e) {
/* 1056 */       String m = e.getMessage();
/* 1057 */       if (m == null) m = ""; 
/* 1058 */       String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */       
/* 1060 */       String s = Messages.formatMessage("property.syntax.error.at", new Object[] { u, prop, value, m });
/*      */ 
/*      */       
/* 1063 */       DOMException de = new DOMException((short)12, s);
/* 1064 */       if (this.userAgent == null) throw de; 
/* 1065 */       this.userAgent.displayError(de);
/*      */     } finally {
/* 1067 */       this.element = null;
/* 1068 */       this.cssBaseURI = null;
/*      */     } 
/* 1070 */     return vm.getDefaultValue();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public StyleDeclaration parseStyleDeclaration(CSSStylableElement elt, String value) {
/* 1079 */     this.styleDeclarationBuilder.styleDeclaration = new StyleDeclaration();
/*      */     try {
/* 1081 */       this.element = elt;
/* 1082 */       this.parser.setSelectorFactory(CSSSelectorFactory.INSTANCE);
/* 1083 */       this.parser.setConditionFactory(this.cssConditionFactory);
/* 1084 */       this.parser.setDocumentHandler(this.styleDeclarationBuilder);
/* 1085 */       this.parser.parseStyleDeclaration(value);
/*      */     } catch (Exception e) {
/* 1087 */       String m = e.getMessage();
/* 1088 */       if (m == null) m = ""; 
/* 1089 */       String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */       
/* 1091 */       String s = Messages.formatMessage("syntax.error.at", new Object[] { u, m });
/*      */       
/* 1093 */       DOMException de = new DOMException((short)12, s);
/* 1094 */       if (this.userAgent == null) throw de; 
/* 1095 */       this.userAgent.displayError(de);
/*      */     } finally {
/* 1097 */       this.element = null;
/* 1098 */       this.cssBaseURI = null;
/*      */     } 
/* 1100 */     return this.styleDeclarationBuilder.styleDeclaration;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public StyleSheet parseStyleSheet(ParsedURL uri, String media) throws DOMException {
/* 1110 */     StyleSheet ss = new StyleSheet();
/*      */     try {
/* 1112 */       ss.setMedia(this.parser.parseMedia(media));
/*      */     } catch (Exception e) {
/* 1114 */       String m = e.getMessage();
/* 1115 */       if (m == null) m = ""; 
/* 1116 */       String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */       
/* 1118 */       String s = Messages.formatMessage("syntax.error.at", new Object[] { u, m });
/*      */       
/* 1120 */       DOMException de = new DOMException((short)12, s);
/* 1121 */       if (this.userAgent == null) throw de; 
/* 1122 */       this.userAgent.displayError(de);
/* 1123 */       return ss;
/*      */     } 
/* 1125 */     parseStyleSheet(ss, uri);
/* 1126 */     return ss;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public StyleSheet parseStyleSheet(InputSource is, ParsedURL uri, String media) throws DOMException {
/* 1138 */     StyleSheet ss = new StyleSheet();
/*      */     try {
/* 1140 */       ss.setMedia(this.parser.parseMedia(media));
/* 1141 */       parseStyleSheet(ss, is, uri);
/*      */     } catch (Exception e) {
/* 1143 */       String m = e.getMessage();
/* 1144 */       if (m == null) m = ""; 
/* 1145 */       String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */       
/* 1147 */       String s = Messages.formatMessage("syntax.error.at", new Object[] { u, m });
/*      */       
/* 1149 */       DOMException de = new DOMException((short)12, s);
/* 1150 */       if (this.userAgent == null) throw de; 
/* 1151 */       this.userAgent.displayError(de);
/*      */     } 
/* 1153 */     return ss;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseStyleSheet(StyleSheet ss, ParsedURL uri) throws DOMException {
/* 1163 */     if (uri == null) {
/* 1164 */       String s = Messages.formatMessage("syntax.error.at", new Object[] { "Null Document reference", "" });
/*      */ 
/*      */       
/* 1167 */       DOMException de = new DOMException((short)12, s);
/* 1168 */       if (this.userAgent == null) throw de; 
/* 1169 */       this.userAgent.displayError(de);
/*      */       
/*      */       return;
/*      */     } 
/*      */     
/*      */     try {
/* 1175 */       this.cssContext.checkLoadExternalResource(uri, this.documentURI);
/* 1176 */       parseStyleSheet(ss, new InputSource(uri.toString()), uri);
/*      */     } catch (SecurityException e) {
/* 1178 */       throw e;
/*      */     } catch (Exception e) {
/* 1180 */       String m = e.getMessage();
/* 1181 */       if (m == null) m = e.getClass().getName(); 
/* 1182 */       String s = Messages.formatMessage("syntax.error.at", new Object[] { uri.toString(), m });
/*      */       
/* 1184 */       DOMException de = new DOMException((short)12, s);
/* 1185 */       if (this.userAgent == null) throw de; 
/* 1186 */       this.userAgent.displayError(de);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public StyleSheet parseStyleSheet(String rules, ParsedURL uri, String media) throws DOMException {
/* 1198 */     StyleSheet ss = new StyleSheet();
/*      */     try {
/* 1200 */       ss.setMedia(this.parser.parseMedia(media));
/*      */     } catch (Exception e) {
/* 1202 */       String m = e.getMessage();
/* 1203 */       if (m == null) m = ""; 
/* 1204 */       String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */       
/* 1206 */       String s = Messages.formatMessage("syntax.error.at", new Object[] { u, m });
/*      */       
/* 1208 */       DOMException de = new DOMException((short)12, s);
/* 1209 */       if (this.userAgent == null) throw de; 
/* 1210 */       this.userAgent.displayError(de);
/* 1211 */       return ss;
/*      */     } 
/* 1213 */     parseStyleSheet(ss, rules, uri);
/* 1214 */     return ss;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseStyleSheet(StyleSheet ss, String rules, ParsedURL uri) throws DOMException {
/*      */     try {
/* 1227 */       parseStyleSheet(ss, new InputSource(new StringReader(rules)), uri);
/*      */     } catch (Exception e) {
/*      */       
/* 1230 */       String m = e.getMessage();
/* 1231 */       if (m == null) m = ""; 
/* 1232 */       String s = Messages.formatMessage("stylesheet.syntax.error", new Object[] { uri.toString(), rules, m });
/*      */ 
/*      */       
/* 1235 */       DOMException de = new DOMException((short)12, s);
/* 1236 */       if (this.userAgent == null) throw de; 
/* 1237 */       this.userAgent.displayError(de);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseStyleSheet(StyleSheet ss, InputSource is, ParsedURL uri) throws IOException {
/* 1248 */     this.parser.setSelectorFactory(CSSSelectorFactory.INSTANCE);
/* 1249 */     this.parser.setConditionFactory(this.cssConditionFactory);
/*      */     try {
/* 1251 */       this.cssBaseURI = uri;
/* 1252 */       this.styleSheetDocumentHandler.styleSheet = ss;
/* 1253 */       this.parser.setDocumentHandler(this.styleSheetDocumentHandler);
/* 1254 */       this.parser.parseStyleSheet(is);
/*      */ 
/*      */       
/* 1257 */       int len = ss.getSize();
/* 1258 */       for (int i = 0; i < len; i++) {
/* 1259 */         Rule r = ss.getRule(i);
/* 1260 */         if (r.getType() != 2) {
/*      */           break;
/*      */         }
/*      */         
/* 1264 */         ImportRule ir = (ImportRule)r;
/* 1265 */         parseStyleSheet(ir, ir.getURI());
/*      */       } 
/*      */     } finally {
/* 1268 */       this.cssBaseURI = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void putAuthorProperty(StyleMap dest, int idx, Value sval, boolean imp, short origin) {
/* 1281 */     Value dval = dest.getValue(idx);
/* 1282 */     short dorg = dest.getOrigin(idx);
/* 1283 */     boolean dimp = dest.isImportant(idx);
/*      */     
/* 1285 */     boolean cond = (dval == null);
/* 1286 */     if (!cond) {
/* 1287 */       switch (dorg) {
/*      */         case 8192:
/* 1289 */           cond = !dimp;
/*      */           break;
/*      */         case 24576:
/* 1292 */           cond = (!dimp || imp);
/*      */           break;
/*      */         case -24576:
/* 1295 */           cond = false;
/*      */           break;
/*      */         default:
/* 1298 */           cond = true;
/*      */           break;
/*      */       } 
/*      */     }
/* 1302 */     if (cond) {
/* 1303 */       dest.putValue(idx, sval);
/* 1304 */       dest.putImportant(idx, imp);
/* 1305 */       dest.putOrigin(idx, origin);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void addMatchingRules(List rules, StyleSheet ss, Element elt, String pseudo) {
/* 1317 */     int len = ss.getSize();
/* 1318 */     for (int i = 0; i < len; i++) {
/* 1319 */       MediaRule mr; int j, slen; SelectorList sl; StyleRule style; Rule r = ss.getRule(i);
/* 1320 */       switch (r.getType()) {
/*      */         case 0:
/* 1322 */           style = (StyleRule)r;
/* 1323 */           sl = style.getSelectorList();
/* 1324 */           slen = sl.getLength();
/* 1325 */           for (j = 0; j < slen; j++) {
/* 1326 */             ExtendedSelector s = (ExtendedSelector)sl.item(j);
/* 1327 */             if (s.match(elt, pseudo)) {
/* 1328 */               rules.add(style);
/*      */             }
/*      */           } 
/*      */           break;
/*      */         
/*      */         case 1:
/*      */         case 2:
/* 1335 */           mr = (MediaRule)r;
/* 1336 */           if (mediaMatch(mr.getMediaList())) {
/* 1337 */             addMatchingRules(rules, mr, elt, pseudo);
/*      */           }
/*      */           break;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void addRules(Element elt, String pseudo, StyleMap sm, ArrayList rules, short origin) {
/* 1352 */     sortRules(rules, elt, pseudo);
/* 1353 */     int rlen = rules.size();
/*      */     
/* 1355 */     if (origin == 24576) {
/* 1356 */       for (int r = 0; r < rlen; r++) {
/* 1357 */         StyleRule sr = (StyleRule)rules.get(r);
/* 1358 */         StyleDeclaration sd = sr.getStyleDeclaration();
/* 1359 */         int len = sd.size();
/* 1360 */         for (int i = 0; i < len; i++) {
/* 1361 */           putAuthorProperty(sm, sd.getIndex(i), sd.getValue(i), sd.getPriority(i), origin);
/*      */         
/*      */         }
/*      */       }
/*      */     
/*      */     }
/*      */     else {
/*      */       
/* 1369 */       for (int r = 0; r < rlen; r++) {
/* 1370 */         StyleRule sr = (StyleRule)rules.get(r);
/* 1371 */         StyleDeclaration sd = sr.getStyleDeclaration();
/* 1372 */         int len = sd.size();
/* 1373 */         for (int i = 0; i < len; i++) {
/* 1374 */           int idx = sd.getIndex(i);
/* 1375 */           sm.putValue(idx, sd.getValue(i));
/* 1376 */           sm.putImportant(idx, sd.getPriority(i));
/* 1377 */           sm.putOrigin(idx, origin);
/*      */         } 
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void sortRules(ArrayList rules, Element elt, String pseudo) {
/* 1388 */     int len = rules.size();
/* 1389 */     int[] specificities = new int[len];
/* 1390 */     for (int i = 0; i < len; i++) {
/* 1391 */       StyleRule r = (StyleRule)rules.get(i);
/* 1392 */       SelectorList sl = r.getSelectorList();
/* 1393 */       int spec = 0;
/* 1394 */       int slen = sl.getLength();
/* 1395 */       for (int k = 0; k < slen; k++) {
/* 1396 */         ExtendedSelector s = (ExtendedSelector)sl.item(k);
/* 1397 */         if (s.match(elt, pseudo)) {
/* 1398 */           int sp = s.getSpecificity();
/* 1399 */           if (sp > spec) {
/* 1400 */             spec = sp;
/*      */           }
/*      */         } 
/*      */       } 
/* 1404 */       specificities[i] = spec;
/*      */     } 
/* 1406 */     for (int i = 1; i < len; i++) {
/* 1407 */       Object rule = rules.get(i);
/* 1408 */       int spec = specificities[i];
/* 1409 */       int j = i - 1;
/* 1410 */       while (j >= 0 && specificities[j] > spec) {
/* 1411 */         rules.set(j + 1, rules.get(j));
/* 1412 */         specificities[j + 1] = specificities[j];
/* 1413 */         j--;
/*      */       } 
/* 1415 */       rules.set(j + 1, rule);
/* 1416 */       specificities[j + 1] = spec;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean mediaMatch(SACMediaList ml) {
/* 1425 */     if (this.media == null || ml == null || this.media.getLength() == 0 || ml.getLength() == 0)
/*      */     {
/*      */ 
/*      */       
/* 1429 */       return true;
/*      */     }
/* 1431 */     for (int i = 0; i < ml.getLength(); i++) {
/* 1432 */       if (ml.item(i).equalsIgnoreCase("all"))
/* 1433 */         return true; 
/* 1434 */       for (int j = 0; j < this.media.getLength(); j++) {
/* 1435 */         if (this.media.item(j).equalsIgnoreCase("all") || ml.item(i).equalsIgnoreCase(this.media.item(j)))
/*      */         {
/* 1437 */           return true;
/*      */         }
/*      */       } 
/*      */     } 
/* 1441 */     return false;
/*      */   }
/*      */   
/*      */   protected class StyleDeclarationDocumentHandler extends DocumentAdapter implements ShorthandManager.PropertyHandler { public StyleMap styleMap;
/*      */     private final CSSEngine this$0;
/*      */     
/* 1447 */     protected StyleDeclarationDocumentHandler(CSSEngine this$0) { this.this$0 = this$0; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void property(String name, LexicalUnit value, boolean important) throws CSSException {
/* 1458 */       int i = this.this$0.getPropertyIndex(name);
/* 1459 */       if (i == -1) {
/* 1460 */         i = this.this$0.getShorthandIndex(name);
/* 1461 */         if (i == -1) {
/*      */           return;
/*      */         }
/*      */         
/* 1465 */         this.this$0.shorthandManagers[i].setValues(this.this$0, this, value, important);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/* 1470 */         Value v = this.this$0.valueManagers[i].createValue(value, this.this$0);
/* 1471 */         this.this$0.putAuthorProperty(this.styleMap, i, v, important, -32768);
/*      */       } 
/*      */     } }
/*      */ 
/*      */   
/*      */   protected class StyleDeclarationBuilder extends DocumentAdapter implements ShorthandManager.PropertyHandler {
/*      */     public StyleDeclaration styleDeclaration;
/*      */     private final CSSEngine this$0;
/*      */     
/* 1480 */     protected StyleDeclarationBuilder(CSSEngine this$0) { this.this$0 = this$0; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void property(String name, LexicalUnit value, boolean important) throws CSSException {
/* 1491 */       int i = this.this$0.getPropertyIndex(name);
/* 1492 */       if (i == -1) {
/* 1493 */         i = this.this$0.getShorthandIndex(name);
/* 1494 */         if (i == -1) {
/*      */           return;
/*      */         }
/*      */         
/* 1498 */         this.this$0.shorthandManagers[i].setValues(this.this$0, this, value, important);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/* 1503 */         Value v = this.this$0.valueManagers[i].createValue(value, this.this$0);
/* 1504 */         this.styleDeclaration.append(v, i, important);
/*      */       } 
/*      */     } }
/*      */   protected class StyleSheetDocumentHandler extends DocumentAdapter implements ShorthandManager.PropertyHandler { public StyleSheet styleSheet;
/*      */     protected StyleRule styleRule;
/*      */     protected StyleDeclaration styleDeclaration;
/*      */     private final CSSEngine this$0;
/*      */     
/* 1512 */     protected StyleSheetDocumentHandler(CSSEngine this$0) { this.this$0 = this$0; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void startDocument(InputSource source) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void endDocument(InputSource source) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void ignorableAtRule(String atRule) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void importStyle(String uri, SACMediaList media, String defaultNamespaceURI) {
/*      */       ParsedURL parsedURL;
/* 1549 */       ImportRule ir = new ImportRule();
/* 1550 */       ir.setMediaList(media);
/* 1551 */       ir.setParent(this.styleSheet);
/* 1552 */       ParsedURL base = this.this$0.getCSSBaseURI();
/*      */       
/* 1554 */       if (base == null) {
/* 1555 */         parsedURL = new ParsedURL(uri);
/*      */       } else {
/* 1557 */         parsedURL = new ParsedURL(base, uri);
/*      */       } 
/* 1559 */       ir.setURI(parsedURL);
/* 1560 */       this.styleSheet.append(ir);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void startMedia(SACMediaList media) {
/* 1568 */       MediaRule mr = new MediaRule();
/* 1569 */       mr.setMediaList(media);
/* 1570 */       mr.setParent(this.styleSheet);
/* 1571 */       this.styleSheet.append(mr);
/* 1572 */       this.styleSheet = mr;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1580 */     public void endMedia(SACMediaList media) { this.styleSheet = this.styleSheet.getParent(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void startPage(String name, String pseudo_page) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void endPage(String name, String pseudo_page) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1604 */     public void startFontFace() { this.styleDeclaration = new StyleDeclaration(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void endFontFace() {
/* 1612 */       StyleMap sm = new StyleMap(this.this$0.getNumberOfProperties());
/* 1613 */       int len = this.styleDeclaration.size();
/* 1614 */       for (int i = 0; i < len; i++) {
/* 1615 */         int idx = this.styleDeclaration.getIndex(i);
/* 1616 */         sm.putValue(idx, this.styleDeclaration.getValue(i));
/* 1617 */         sm.putImportant(idx, this.styleDeclaration.getPriority(i));
/*      */         
/* 1619 */         sm.putOrigin(idx, (short)24576);
/*      */       } 
/* 1621 */       this.styleDeclaration = null;
/*      */       
/* 1623 */       int pidx = this.this$0.getPropertyIndex("font-family");
/* 1624 */       Value fontFamily = sm.getValue(pidx);
/* 1625 */       if (fontFamily == null)
/*      */         return; 
/* 1627 */       ParsedURL base = this.this$0.getCSSBaseURI();
/* 1628 */       this.this$0.fontFaces.add(new FontFaceRule(sm, base));
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void startSelector(SelectorList selectors) {
/* 1636 */       this.styleRule = new StyleRule();
/* 1637 */       this.styleRule.setSelectorList(selectors);
/* 1638 */       this.styleDeclaration = new StyleDeclaration();
/* 1639 */       this.styleRule.setStyleDeclaration(this.styleDeclaration);
/* 1640 */       this.styleSheet.append(this.styleRule);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void endSelector(SelectorList selectors) {
/* 1648 */       this.styleRule = null;
/* 1649 */       this.styleDeclaration = null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void property(String name, LexicalUnit value, boolean important) throws CSSException {
/* 1658 */       int i = this.this$0.getPropertyIndex(name);
/* 1659 */       if (i == -1) {
/* 1660 */         i = this.this$0.getShorthandIndex(name);
/* 1661 */         if (i == -1) {
/*      */           return;
/*      */         }
/*      */         
/* 1665 */         this.this$0.shorthandManagers[i].setValues(this.this$0, this, value, important);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/* 1670 */         Value v = this.this$0.valueManagers[i].createValue(value, this.this$0);
/* 1671 */         this.styleDeclaration.append(v, i, important);
/*      */       } 
/*      */     } }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static class DocumentAdapter
/*      */     implements DocumentHandler
/*      */   {
/* 1688 */     public void startDocument(InputSource source) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1696 */     public void endDocument(InputSource source) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void comment(String text) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1712 */     public void ignorableAtRule(String atRule) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1720 */     public void namespaceDeclaration(String prefix, String uri) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1730 */     public void importStyle(String uri, SACMediaList media, String defaultNamespaceURI) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1738 */     public void startMedia(SACMediaList media) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1746 */     public void endMedia(SACMediaList media) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1754 */     public void startPage(String name, String pseudo_page) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1762 */     public void endPage(String name, String pseudo_page) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1769 */     public void startFontFace() { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1776 */     public void endFontFace() { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1784 */     public void startSelector(SelectorList selectors) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1792 */     public void endSelector(SelectorList selectors) { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1800 */     public void property(String name, LexicalUnit value, boolean important) throws CSSException { throwUnsupportedEx(); }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1805 */     private void throwUnsupportedEx() { throw new UnsupportedOperationException("you try to use an empty method in Adapter-class"); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1811 */   protected static final CSSEngineListener[] LISTENER_ARRAY = new CSSEngineListener[0];
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1818 */   public void addCSSEngineListener(CSSEngineListener l) { this.listeners.add(l); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1825 */   public void removeCSSEngineListener(CSSEngineListener l) { this.listeners.remove(l); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void firePropertiesChangedEvent(Element target, int[] props) {
/* 1832 */     CSSEngineListener[] ll = (CSSEngineListener[])this.listeners.toArray(LISTENER_ARRAY);
/*      */ 
/*      */     
/* 1835 */     int len = ll.length;
/* 1836 */     if (len > 0) {
/* 1837 */       CSSEngineEvent evt = new CSSEngineEvent(this, target, props);
/* 1838 */       for (int i = 0; i < len; i++) {
/* 1839 */         ll[i].propertiesChanged(evt);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void inlineStyleAttributeUpdated(CSSStylableElement elt, StyleMap style, short attrChange, String prevValue, String newValue) {
/* 1854 */     boolean removed, updated[] = this.styleDeclarationUpdateHandler.updatedProperties;
/* 1855 */     for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 1856 */       updated[i] = false;
/*      */     }
/*      */     
/* 1859 */     switch (attrChange) {
/*      */       case 1:
/*      */       case 2:
/* 1862 */         if (newValue.length() > 0) {
/* 1863 */           this.element = elt;
/*      */           try {
/* 1865 */             this.parser.setSelectorFactory(CSSSelectorFactory.INSTANCE);
/* 1866 */             this.parser.setConditionFactory(this.cssConditionFactory);
/* 1867 */             this.styleDeclarationUpdateHandler.styleMap = style;
/* 1868 */             this.parser.setDocumentHandler(this.styleDeclarationUpdateHandler);
/* 1869 */             this.parser.parseStyleDeclaration(newValue);
/* 1870 */             this.styleDeclarationUpdateHandler.styleMap = null;
/*      */           } catch (Exception e) {
/* 1872 */             String m = e.getMessage();
/* 1873 */             if (m == null) m = ""; 
/* 1874 */             String u = (this.documentURI == null) ? "<unknown>" : this.documentURI.toString();
/*      */             
/* 1876 */             String s = Messages.formatMessage("style.syntax.error.at", new Object[] { u, this.styleLocalName, newValue, m });
/*      */ 
/*      */             
/* 1879 */             DOMException de = new DOMException((short)12, s);
/* 1880 */             if (this.userAgent == null) throw de; 
/* 1881 */             this.userAgent.displayError(de);
/*      */           } finally {
/* 1883 */             this.element = null;
/* 1884 */             this.cssBaseURI = null;
/*      */           } 
/*      */         } 
/*      */ 
/*      */       
/*      */       case 3:
/* 1890 */         removed = false;
/*      */         
/* 1892 */         if (prevValue != null && prevValue.length() > 0)
/*      */         {
/*      */           
/* 1895 */           for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 1896 */             if (style.isComputed(i) && !updated[i]) {
/* 1897 */               short origin = style.getOrigin(i);
/* 1898 */               if (origin >= Short.MIN_VALUE) {
/* 1899 */                 removed = true;
/* 1900 */                 updated[i] = true;
/*      */               } 
/*      */             } 
/*      */           } 
/*      */         }
/*      */         
/* 1906 */         if (removed) {
/* 1907 */           invalidateProperties(elt, null, updated, true);
/*      */         } else {
/* 1909 */           int count = 0;
/*      */           
/* 1911 */           boolean fs = (this.fontSizeIndex == -1) ? false : updated[this.fontSizeIndex];
/*      */ 
/*      */           
/* 1914 */           boolean lh = (this.lineHeightIndex == -1) ? false : updated[this.lineHeightIndex];
/*      */ 
/*      */           
/* 1917 */           boolean cl = (this.colorIndex == -1) ? false : updated[this.colorIndex];
/*      */ 
/*      */ 
/*      */           
/* 1921 */           for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 1922 */             if (updated[i]) {
/* 1923 */               count++;
/*      */             }
/* 1925 */             else if ((fs && style.isFontSizeRelative(i)) || (lh && style.isLineHeightRelative(i)) || (cl && style.isColorRelative(i))) {
/*      */ 
/*      */               
/* 1928 */               updated[i] = true;
/* 1929 */               clearComputedValue(style, i);
/* 1930 */               count++;
/*      */             } 
/*      */           } 
/*      */           
/* 1934 */           if (count > 0) {
/* 1935 */             int[] props = new int[count];
/* 1936 */             count = 0;
/* 1937 */             for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 1938 */               if (updated[i]) {
/* 1939 */                 props[count++] = i;
/*      */               }
/*      */             } 
/* 1942 */             invalidateProperties(elt, props, null, true);
/*      */           } 
/*      */         } 
/*      */         return;
/*      */     } 
/*      */ 
/*      */     
/* 1949 */     throw new IllegalStateException("Invalid attrChangeType");
/*      */   }
/*      */ 
/*      */   
/*      */   private static void clearComputedValue(StyleMap style, int n) {
/* 1954 */     if (style.isNullCascaded(n)) {
/* 1955 */       style.putValue(n, null);
/*      */     } else {
/* 1957 */       Value v = style.getValue(n);
/* 1958 */       if (v instanceof ComputedValue) {
/* 1959 */         ComputedValue cv = (ComputedValue)v;
/* 1960 */         v = cv.getCascadedValue();
/* 1961 */         style.putValue(n, v);
/*      */       } 
/*      */     } 
/* 1964 */     style.putComputed(n, false);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void invalidateProperties(Node node, int[] properties, boolean[] updated, boolean recascade) {
/* 1975 */     if (!(node instanceof CSSStylableElement)) {
/*      */       return;
/*      */     }
/* 1978 */     CSSStylableElement elt = (CSSStylableElement)node;
/* 1979 */     StyleMap style = elt.getComputedStyleMap(null);
/* 1980 */     if (style == null) {
/*      */       return;
/*      */     }
/* 1983 */     boolean[] diffs = new boolean[getNumberOfProperties()];
/* 1984 */     if (updated != null) {
/* 1985 */       System.arraycopy(updated, 0, diffs, 0, updated.length);
/*      */     }
/* 1987 */     if (properties != null) {
/* 1988 */       for (int i = 0; i < properties.length; i++) {
/* 1989 */         diffs[properties[i]] = true;
/*      */       }
/*      */     }
/* 1992 */     int count = 0;
/* 1993 */     if (!recascade) {
/* 1994 */       for (int i = 0; i < diffs.length; i++) {
/* 1995 */         if (diffs[i]) {
/* 1996 */           count++;
/*      */         }
/*      */       } 
/*      */     } else {
/* 2000 */       StyleMap newStyle = getCascadedStyleMap(elt, null);
/* 2001 */       elt.setComputedStyleMap(null, newStyle);
/* 2002 */       for (int i = 0; i < diffs.length; i++) {
/* 2003 */         if (diffs[i]) {
/* 2004 */           count++;
/*      */           
/*      */           continue;
/*      */         } 
/*      */         
/* 2009 */         Value nv = newStyle.getValue(i);
/* 2010 */         Value ov = null;
/* 2011 */         if (!style.isNullCascaded(i)) {
/* 2012 */           ov = style.getValue(i);
/* 2013 */           if (ov instanceof ComputedValue) {
/* 2014 */             ov = ((ComputedValue)ov).getCascadedValue();
/*      */           }
/*      */         } 
/*      */         
/* 2018 */         if (nv == ov)
/* 2019 */           continue;  if (nv != null && ov != null) {
/* 2020 */           if (nv.equals(ov))
/* 2021 */             continue;  String ovCssText = ov.getCssText();
/* 2022 */           String nvCssText = nv.getCssText();
/* 2023 */           if (nvCssText == ovCssText || (nvCssText != null && nvCssText.equals(ovCssText))) {
/*      */             continue;
/*      */           }
/*      */         } 
/* 2027 */         count++;
/* 2028 */         diffs[i] = true; continue;
/*      */       } 
/*      */     } 
/* 2031 */     int[] props = null;
/* 2032 */     if (count != 0) {
/* 2033 */       props = new int[count];
/* 2034 */       count = 0;
/* 2035 */       for (int i = 0; i < diffs.length; i++) {
/* 2036 */         if (diffs[i])
/* 2037 */           props[count++] = i; 
/*      */       } 
/*      */     } 
/* 2040 */     propagateChanges(elt, props, recascade);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void propagateChanges(Node node, int[] props, boolean recascade) {
/* 2052 */     if (!(node instanceof CSSStylableElement))
/*      */       return; 
/* 2054 */     CSSStylableElement elt = (CSSStylableElement)node;
/* 2055 */     StyleMap style = elt.getComputedStyleMap(null);
/* 2056 */     if (style != null) {
/* 2057 */       boolean[] updated = this.styleDeclarationUpdateHandler.updatedProperties;
/*      */       
/* 2059 */       for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 2060 */         updated[i] = false;
/*      */       }
/* 2062 */       if (props != null) {
/* 2063 */         for (int i = props.length - 1; i >= 0; i--) {
/* 2064 */           int idx = props[i];
/* 2065 */           updated[idx] = true;
/*      */         } 
/*      */       }
/*      */ 
/*      */       
/* 2070 */       boolean fs = (this.fontSizeIndex == -1) ? false : updated[this.fontSizeIndex];
/*      */ 
/*      */       
/* 2073 */       boolean lh = (this.lineHeightIndex == -1) ? false : updated[this.lineHeightIndex];
/*      */ 
/*      */       
/* 2076 */       boolean cl = (this.colorIndex == -1) ? false : updated[this.colorIndex];
/*      */ 
/*      */ 
/*      */       
/* 2080 */       int count = 0;
/* 2081 */       for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 2082 */         if (updated[i]) {
/* 2083 */           count++;
/*      */         }
/* 2085 */         else if ((fs && style.isFontSizeRelative(i)) || (lh && style.isLineHeightRelative(i)) || (cl && style.isColorRelative(i))) {
/*      */ 
/*      */           
/* 2088 */           updated[i] = true;
/* 2089 */           clearComputedValue(style, i);
/* 2090 */           count++;
/*      */         } 
/*      */       } 
/*      */       
/* 2094 */       if (count == 0) {
/* 2095 */         props = null;
/*      */       } else {
/* 2097 */         props = new int[count];
/* 2098 */         count = 0;
/* 2099 */         for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 2100 */           if (updated[i]) {
/* 2101 */             props[count++] = i;
/*      */           }
/*      */         } 
/* 2104 */         firePropertiesChangedEvent(elt, props);
/*      */       } 
/*      */     } 
/*      */     
/* 2108 */     int[] inherited = props;
/* 2109 */     if (props != null) {
/*      */ 
/*      */       
/* 2112 */       int count = 0;
/* 2113 */       for (int i = 0; i < props.length; i++) {
/* 2114 */         ValueManager vm = this.valueManagers[props[i]];
/* 2115 */         if (vm.isInheritedProperty()) { count++; }
/* 2116 */         else { props[i] = -1; }
/*      */       
/*      */       } 
/* 2119 */       if (count == 0) {
/*      */         
/* 2121 */         inherited = null;
/*      */       } else {
/* 2123 */         inherited = new int[count];
/* 2124 */         count = 0;
/* 2125 */         for (int i = 0; i < props.length; i++) {
/* 2126 */           if (props[i] != -1)
/* 2127 */             inherited[count++] = props[i]; 
/*      */         } 
/*      */       } 
/*      */     } 
/* 2131 */     Node n = getCSSFirstChild(node);
/* 2132 */     for (; n != null; 
/* 2133 */       n = getCSSNextSibling(n)) {
/* 2134 */       if (n.getNodeType() == 1)
/*      */       {
/*      */ 
/*      */ 
/*      */         
/* 2139 */         invalidateProperties(n, inherited, null, recascade); } 
/*      */     } 
/*      */   }
/*      */   protected class StyleDeclarationUpdateHandler extends DocumentAdapter implements ShorthandManager.PropertyHandler { public StyleMap styleMap;
/*      */     public boolean[] updatedProperties;
/*      */     private final CSSEngine this$0;
/*      */     
/*      */     protected StyleDeclarationUpdateHandler(CSSEngine this$0) {
/* 2147 */       this.this$0 = this$0;
/*      */ 
/*      */ 
/*      */       
/* 2151 */       this.updatedProperties = new boolean[this.this$0.getNumberOfProperties()];
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void property(String name, LexicalUnit value, boolean important) throws CSSException {
/* 2160 */       int i = this.this$0.getPropertyIndex(name);
/* 2161 */       if (i == -1) {
/* 2162 */         i = this.this$0.getShorthandIndex(name);
/* 2163 */         if (i == -1) {
/*      */           return;
/*      */         }
/*      */         
/* 2167 */         this.this$0.shorthandManagers[i].setValues(this.this$0, this, value, important);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/* 2172 */         if (this.styleMap.isImportant(i)) {
/*      */           return;
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2178 */         this.updatedProperties[i] = true;
/*      */         
/* 2180 */         Value v = this.this$0.valueManagers[i].createValue(value, this.this$0);
/* 2181 */         this.styleMap.putMask(i, (short)0);
/* 2182 */         this.styleMap.putValue(i, v);
/* 2183 */         this.styleMap.putOrigin(i, -32768);
/*      */       } 
/*      */     } }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void nonCSSPresentationalHintUpdated(CSSStylableElement elt, StyleMap style, String property, short attrChange, String newValue) {
/* 2196 */     int invalid[], idx = getPropertyIndex(property);
/*      */     
/* 2198 */     if (style.isImportant(idx)) {
/*      */       return;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 2204 */     if (style.getOrigin(idx) >= 24576) {
/*      */       return;
/*      */     }
/*      */ 
/*      */     
/* 2209 */     switch (attrChange) {
/*      */       case 1:
/*      */       case 2:
/* 2212 */         this.element = elt;
/*      */         
/*      */         try {
/* 2215 */           LexicalUnit lu = this.parser.parsePropertyValue(newValue);
/* 2216 */           ValueManager vm = this.valueManagers[idx];
/* 2217 */           Value v = vm.createValue(lu, this);
/* 2218 */           style.putMask(idx, (short)0);
/* 2219 */           style.putValue(idx, v);
/* 2220 */           style.putOrigin(idx, (short)16384);
/*      */         } catch (Exception e) {
/* 2222 */           String m = e.getMessage();
/*      */         } finally {
/*      */           API aPI;
/*      */         } 
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 3:
/* 2240 */         invalid = new int[] { idx };
/* 2241 */         invalidateProperties(elt, invalid, null, true);
/*      */         return;
/*      */     } 
/*      */ 
/*      */     
/* 2246 */     boolean[] updated = this.styleDeclarationUpdateHandler.updatedProperties;
/* 2247 */     for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 2248 */       updated[i] = false;
/*      */     }
/* 2250 */     updated[idx] = true;
/*      */ 
/*      */     
/* 2253 */     boolean fs = (idx == this.fontSizeIndex);
/* 2254 */     boolean lh = (idx == this.lineHeightIndex);
/* 2255 */     boolean cl = (idx == this.colorIndex);
/* 2256 */     int count = 0;
/*      */     
/* 2258 */     for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 2259 */       if (updated[i]) {
/* 2260 */         count++;
/*      */       }
/* 2262 */       else if ((fs && style.isFontSizeRelative(i)) || (lh && style.isLineHeightRelative(i)) || (cl && style.isColorRelative(i))) {
/*      */ 
/*      */         
/* 2265 */         updated[i] = true;
/* 2266 */         clearComputedValue(style, i);
/* 2267 */         count++;
/*      */       } 
/*      */     } 
/*      */     
/* 2271 */     int[] props = new int[count];
/* 2272 */     count = 0;
/* 2273 */     for (int i = getNumberOfProperties() - 1; i >= 0; i--) {
/* 2274 */       if (updated[i]) {
/* 2275 */         props[count++] = i;
/*      */       }
/*      */     } 
/*      */     
/* 2279 */     invalidateProperties(elt, props, null, true);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean hasStyleSheetNode(Node n) {
/* 2287 */     if (n instanceof CSSStyleSheetNode) {
/* 2288 */       return true;
/*      */     }
/* 2290 */     n = getCSSFirstChild(n);
/* 2291 */     while (n != null) {
/* 2292 */       if (hasStyleSheetNode(n)) {
/* 2293 */         return true;
/*      */       }
/* 2295 */       n = getCSSNextSibling(n);
/*      */     } 
/* 2297 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void handleAttrModified(Element e, Attr attr, short attrChange, String prevValue, String newValue) {
/* 2308 */     if (!(e instanceof CSSStylableElement)) {
/*      */       return;
/*      */     }
/*      */ 
/*      */     
/* 2313 */     if (newValue.equals(prevValue)) {
/*      */       return;
/*      */     }
/*      */     
/* 2317 */     String attrNS = attr.getNamespaceURI();
/* 2318 */     String name = (attrNS == null) ? attr.getNodeName() : attr.getLocalName();
/*      */     
/* 2320 */     CSSStylableElement elt = (CSSStylableElement)e;
/* 2321 */     StyleMap style = elt.getComputedStyleMap(null);
/* 2322 */     if (style != null) {
/* 2323 */       if (attrNS == this.styleNamespaceURI || (attrNS != null && attrNS.equals(this.styleNamespaceURI)))
/*      */       {
/* 2325 */         if (name.equals(this.styleLocalName)) {
/*      */           
/* 2327 */           inlineStyleAttributeUpdated(elt, style, attrChange, prevValue, newValue);
/*      */           
/*      */           return;
/*      */         } 
/*      */       }
/*      */       
/* 2333 */       if (this.nonCSSPresentationalHints != null && (
/* 2334 */         attrNS == this.nonCSSPresentationalHintsNamespaceURI || (attrNS != null && attrNS.equals(this.nonCSSPresentationalHintsNamespaceURI))))
/*      */       {
/*      */         
/* 2337 */         if (this.nonCSSPresentationalHints.contains(name)) {
/*      */ 
/*      */           
/* 2340 */           nonCSSPresentationalHintUpdated(elt, style, name, attrChange, newValue);
/*      */ 
/*      */           
/*      */           return;
/*      */         } 
/*      */       }
/*      */     } 
/*      */     
/* 2348 */     if (this.selectorAttributes != null && this.selectorAttributes.contains(name)) {
/*      */ 
/*      */ 
/*      */       
/* 2352 */       invalidateProperties(elt, null, null, true);
/* 2353 */       Node n = getCSSNextSibling(elt);
/* 2354 */       for (; n != null; 
/* 2355 */         n = getCSSNextSibling(n)) {
/* 2356 */         invalidateProperties(n, null, null, true);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void handleNodeInserted(Node n) {
/* 2365 */     if (hasStyleSheetNode(n)) {
/*      */       
/* 2367 */       this.styleSheetNodes = null;
/* 2368 */       invalidateProperties(this.document.getDocumentElement(), null, null, true);
/*      */     }
/* 2370 */     else if (n instanceof CSSStylableElement) {
/*      */ 
/*      */       
/* 2373 */       n = getCSSNextSibling(n);
/* 2374 */       while (n != null) {
/* 2375 */         invalidateProperties(n, null, null, true);
/* 2376 */         n = getCSSNextSibling(n);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void handleNodeRemoved(Node n) {
/* 2385 */     if (hasStyleSheetNode(n)) {
/*      */ 
/*      */       
/* 2388 */       this.styleSheetRemoved = true;
/* 2389 */     } else if (n instanceof CSSStylableElement) {
/*      */ 
/*      */       
/* 2392 */       this.removedStylableElementSibling = getCSSNextSibling(n);
/*      */     } 
/*      */     
/* 2395 */     disposeStyleMaps(n);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void handleSubtreeModified(Node ignored) {
/* 2404 */     if (this.styleSheetRemoved) {
/*      */       
/* 2406 */       this.styleSheetRemoved = false;
/* 2407 */       this.styleSheetNodes = null;
/* 2408 */       invalidateProperties(this.document.getDocumentElement(), null, null, true);
/*      */     }
/* 2410 */     else if (this.removedStylableElementSibling != null) {
/*      */ 
/*      */ 
/*      */       
/* 2414 */       Node n = this.removedStylableElementSibling;
/* 2415 */       while (n != null) {
/* 2416 */         invalidateProperties(n, null, null, true);
/* 2417 */         n = getCSSNextSibling(n);
/*      */       } 
/* 2419 */       this.removedStylableElementSibling = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void handleCharacterDataModified(Node n) {
/* 2427 */     if (getCSSParentNode(n) instanceof CSSStyleSheetNode) {
/*      */       
/* 2429 */       this.styleSheetNodes = null;
/* 2430 */       invalidateProperties(this.document.getDocumentElement(), null, null, true);
/*      */     } 
/*      */   }
/*      */   
/*      */   protected class CSSNavigableDocumentHandler implements CSSNavigableDocumentListener, MainPropertyReceiver { protected boolean[] mainPropertiesChanged;
/*      */     protected StyleDeclaration declaration;
/*      */     private final CSSEngine this$0;
/*      */     
/* 2438 */     protected CSSNavigableDocumentHandler(CSSEngine this$0) { this.this$0 = this$0; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2457 */     public void nodeInserted(Node newNode) { this.this$0.handleNodeInserted(newNode); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2464 */     public void nodeToBeRemoved(Node oldNode) { this.this$0.handleNodeRemoved(oldNode); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2472 */     public void subtreeModified(Node rootOfModifications) { this.this$0.handleSubtreeModified(rootOfModifications); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2479 */     public void characterDataModified(Node text) { this.this$0.handleCharacterDataModified(text); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2490 */     public void attrModified(Element e, Attr attr, short attrChange, String prevValue, String newValue) { this.this$0.handleAttrModified(e, attr, attrChange, prevValue, newValue); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void overrideStyleTextChanged(CSSStylableElement elt, String text) {
/* 2499 */       StyleDeclarationProvider p = elt.getOverrideStyleDeclarationProvider();
/*      */       
/* 2501 */       StyleDeclaration declaration = p.getStyleDeclaration();
/* 2502 */       int ds = declaration.size();
/* 2503 */       boolean[] updated = new boolean[this.this$0.getNumberOfProperties()];
/* 2504 */       for (int i = 0; i < ds; i++) {
/* 2505 */         updated[declaration.getIndex(i)] = true;
/*      */       }
/* 2507 */       declaration = this.this$0.parseStyleDeclaration(elt, text);
/* 2508 */       p.setStyleDeclaration(declaration);
/* 2509 */       ds = declaration.size();
/* 2510 */       for (int i = 0; i < ds; i++) {
/* 2511 */         updated[declaration.getIndex(i)] = true;
/*      */       }
/* 2513 */       this.this$0.invalidateProperties(elt, null, updated, true);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void overrideStylePropertyRemoved(CSSStylableElement elt, String name) {
/* 2521 */       StyleDeclarationProvider p = elt.getOverrideStyleDeclarationProvider();
/*      */       
/* 2523 */       StyleDeclaration declaration = p.getStyleDeclaration();
/* 2524 */       int idx = this.this$0.getPropertyIndex(name);
/* 2525 */       int ds = declaration.size();
/* 2526 */       for (int i = 0; i < ds; i++) {
/* 2527 */         if (idx == declaration.getIndex(i)) {
/* 2528 */           declaration.remove(i);
/* 2529 */           StyleMap style = elt.getComputedStyleMap(null);
/* 2530 */           if (style != null && style.getOrigin(idx) == -24576)
/*      */           {
/*      */             
/* 2533 */             this.this$0.invalidateProperties(elt, new int[] { idx }, null, true);
/*      */           }
/*      */           break;
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void overrideStylePropertyChanged(CSSStylableElement elt, String name, String val, String prio) {
/* 2547 */       boolean important = (prio != null && prio.length() != 0);
/* 2548 */       StyleDeclarationProvider p = elt.getOverrideStyleDeclarationProvider();
/*      */       
/* 2550 */       this.declaration = p.getStyleDeclaration();
/* 2551 */       this.this$0.setMainProperties(elt, this, name, val, important);
/* 2552 */       this.declaration = null;
/* 2553 */       this.this$0.invalidateProperties(elt, null, this.mainPropertiesChanged, true);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void setMainProperty(String name, Value v, boolean important) {
/* 2563 */       int idx = this.this$0.getPropertyIndex(name);
/* 2564 */       if (idx == -1) {
/*      */         return;
/*      */       }
/*      */       
/*      */       int i;
/* 2569 */       for (i = 0; i < this.declaration.size() && 
/* 2570 */         idx != this.declaration.getIndex(i); i++);
/*      */ 
/*      */ 
/*      */       
/* 2574 */       if (i < this.declaration.size()) {
/* 2575 */         this.declaration.put(i, v, idx, important);
/*      */       } else {
/* 2577 */         this.declaration.append(v, idx, important);
/*      */       } 
/*      */     } }
/*      */ 
/*      */   
/*      */   protected class DOMNodeInsertedListener
/*      */     implements EventListener {
/*      */     private final CSSEngine this$0;
/*      */     
/* 2586 */     protected DOMNodeInsertedListener(CSSEngine this$0) { this.this$0 = this$0; }
/*      */     
/* 2588 */     public void handleEvent(Event evt) { this.this$0.handleNodeInserted((Node)evt.getTarget()); }
/*      */   }
/*      */   
/*      */   protected class DOMNodeRemovedListener
/*      */     implements EventListener
/*      */   {
/*      */     private final CSSEngine this$0;
/*      */     
/* 2596 */     protected DOMNodeRemovedListener(CSSEngine this$0) { this.this$0 = this$0; }
/*      */     
/* 2598 */     public void handleEvent(Event evt) { this.this$0.handleNodeRemoved((Node)evt.getTarget()); }
/*      */   }
/*      */   
/*      */   protected class DOMSubtreeModifiedListener
/*      */     implements EventListener
/*      */   {
/*      */     private final CSSEngine this$0;
/*      */     
/* 2606 */     protected DOMSubtreeModifiedListener(CSSEngine this$0) { this.this$0 = this$0; }
/*      */     
/* 2608 */     public void handleEvent(Event evt) { this.this$0.handleSubtreeModified((Node)evt.getTarget()); }
/*      */   }
/*      */   
/*      */   protected class DOMCharacterDataModifiedListener
/*      */     implements EventListener {
/*      */     private final CSSEngine this$0;
/*      */     
/* 2615 */     protected DOMCharacterDataModifiedListener(CSSEngine this$0) { this.this$0 = this$0; }
/*      */     
/* 2617 */     public void handleEvent(Event evt) { this.this$0.handleCharacterDataModified((Node)evt.getTarget()); }
/*      */   }
/*      */   
/*      */   protected class DOMAttrModifiedListener
/*      */     implements EventListener
/*      */   {
/*      */     private final CSSEngine this$0;
/*      */     
/* 2625 */     protected DOMAttrModifiedListener(CSSEngine this$0) { this.this$0 = this$0; }
/*      */     public void handleEvent(Event evt) {
/* 2627 */       MutationEvent mevt = (MutationEvent)evt;
/* 2628 */       this.this$0.handleAttrModified((Element)evt.getTarget(), (Attr)mevt.getRelatedNode(), mevt.getAttrChange(), mevt.getPrevValue(), mevt.getNewValue());
/*      */     }
/*      */   }
/*      */   
/*      */   public static interface MainPropertyReceiver {
/*      */     void setMainProperty(String param1String, Value param1Value, boolean param1Boolean);
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\engine\CSSEngine.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */