/*     */ package org.apache.batik.css.engine;
/*     */ 
/*     */ import org.apache.batik.css.engine.value.Value;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class StyleMap
/*     */ {
/*     */   public static final short IMPORTANT_MASK = 1;
/*     */   public static final short COMPUTED_MASK = 2;
/*     */   public static final short NULL_CASCADED_MASK = 4;
/*     */   public static final short INHERITED_MASK = 8;
/*     */   public static final short LINE_HEIGHT_RELATIVE_MASK = 16;
/*     */   public static final short FONT_SIZE_RELATIVE_MASK = 32;
/*     */   public static final short COLOR_RELATIVE_MASK = 64;
/*     */   public static final short PARENT_RELATIVE_MASK = 128;
/*     */   public static final short BLOCK_WIDTH_RELATIVE_MASK = 256;
/*     */   public static final short BLOCK_HEIGHT_RELATIVE_MASK = 512;
/*     */   public static final short BOX_RELATIVE_MASK = 1024;
/*     */   public static final short ORIGIN_MASK = -8192;
/*     */   public static final short USER_AGENT_ORIGIN = 0;
/*     */   public static final short USER_ORIGIN = 8192;
/*     */   public static final short NON_CSS_ORIGIN = 16384;
/*     */   public static final short AUTHOR_ORIGIN = 24576;
/*     */   public static final short INLINE_AUTHOR_ORIGIN = -32768;
/*     */   public static final short OVERRIDE_ORIGIN = -24576;
/*     */   protected Value[] values;
/*     */   protected short[] masks;
/*     */   protected boolean fixedCascadedValues;
/*     */   
/*     */   public StyleMap(int size) {
/*  79 */     this.values = new Value[size];
/*  80 */     this.masks = new short[size];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  87 */   public boolean hasFixedCascadedValues() { return this.fixedCascadedValues; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  94 */   public void setFixedCascadedStyle(boolean b) { this.fixedCascadedValues = b; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 101 */   public Value getValue(int i) { return this.values[i]; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 108 */   public short getMask(int i) { return this.masks[i]; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 115 */   public boolean isImportant(int i) { return ((this.masks[i] & true) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 122 */   public boolean isComputed(int i) { return ((this.masks[i] & 0x2) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 129 */   public boolean isNullCascaded(int i) { return ((this.masks[i] & 0x4) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 137 */   public boolean isInherited(int i) { return ((this.masks[i] & 0x8) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 144 */   public short getOrigin(int i) { return (short)(this.masks[i] & 0xFFFFE000); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 151 */   public boolean isColorRelative(int i) { return ((this.masks[i] & 0x40) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 159 */   public boolean isParentRelative(int i) { return ((this.masks[i] & 0x80) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 166 */   public boolean isLineHeightRelative(int i) { return ((this.masks[i] & 0x10) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 173 */   public boolean isFontSizeRelative(int i) { return ((this.masks[i] & 0x20) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 181 */   public boolean isBlockWidthRelative(int i) { return ((this.masks[i] & 0x100) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 189 */   public boolean isBlockHeightRelative(int i) { return ((this.masks[i] & 0x200) != 0); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 198 */   public void putValue(int i, Value v) { this.values[i] = v; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 207 */   public void putMask(int i, short m) { this.masks[i] = m; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void putImportant(int i, boolean b) {
/* 214 */     if (b) { this.masks[i] = (short)(this.masks[i] | true); }
/* 215 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFFE); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putOrigin(int i, short val) {
/* 222 */     this.masks[i] = (short)(this.masks[i] & 0x1FFF);
/* 223 */     this.masks[i] = (short)(this.masks[i] | (short)(val & 0xFFFFE000));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void putComputed(int i, boolean b) {
/* 230 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x2); }
/* 231 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFFD); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putNullCascaded(int i, boolean b) {
/* 238 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x4); }
/* 239 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFFB); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void putInherited(int i, boolean b) {
/* 247 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x8); }
/* 248 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFF7); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putColorRelative(int i, boolean b) {
/* 255 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x40); }
/* 256 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFBF); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putParentRelative(int i, boolean b) {
/* 263 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x80); }
/* 264 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFF7F); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putLineHeightRelative(int i, boolean b) {
/* 271 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x10); }
/* 272 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFEF); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putFontSizeRelative(int i, boolean b) {
/* 279 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x20); }
/* 280 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFFDF); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putBlockWidthRelative(int i, boolean b) {
/* 287 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x100); }
/* 288 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFEFF); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void putBlockHeightRelative(int i, boolean b) {
/* 295 */     if (b) { this.masks[i] = (short)(this.masks[i] | 0x200); }
/* 296 */     else { this.masks[i] = (short)(this.masks[i] & 0xFFFFFDFF); }
/*     */   
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String toString(CSSEngine eng) {
/* 306 */     int nSlots = this.values.length;
/* 307 */     StringBuffer sb = new StringBuffer(nSlots * 8);
/* 308 */     for (int i = 0; i < nSlots; i++) {
/* 309 */       Value v = this.values[i];
/* 310 */       if (v != null) {
/*     */         
/* 312 */         sb.append(eng.getPropertyName(i));
/* 313 */         sb.append(": ");
/* 314 */         sb.append(v);
/* 315 */         if (isImportant(i)) sb.append(" !important"); 
/* 316 */         sb.append(";\n");
/*     */       } 
/* 318 */     }  return sb.toString();
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\engine\StyleMap.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */