/*     */ package org.apache.batik.css.engine.value.css2;
/*     */ 
/*     */ import org.apache.batik.css.engine.CSSContext;
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.CSSStylableElement;
/*     */ import org.apache.batik.css.engine.StyleMap;
/*     */ import org.apache.batik.css.engine.value.IdentifierManager;
/*     */ import org.apache.batik.css.engine.value.StringMap;
/*     */ import org.apache.batik.css.engine.value.Value;
/*     */ import org.apache.batik.css.engine.value.ValueConstants;
/*     */ import org.w3c.css.sac.LexicalUnit;
/*     */ import org.w3c.dom.DOMException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class FontWeightManager
/*     */   extends IdentifierManager
/*     */ {
/*  48 */   protected static final StringMap values = new StringMap();
/*     */   static  {
/*  50 */     values.put("all", ValueConstants.ALL_VALUE);
/*     */     
/*  52 */     values.put("bold", ValueConstants.BOLD_VALUE);
/*     */     
/*  54 */     values.put("bolder", ValueConstants.BOLDER_VALUE);
/*     */     
/*  56 */     values.put("lighter", ValueConstants.LIGHTER_VALUE);
/*     */     
/*  58 */     values.put("normal", ValueConstants.NORMAL_VALUE);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  66 */   public boolean isInheritedProperty() { return true; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  73 */   public boolean isAnimatableProperty() { return true; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  80 */   public boolean isAdditiveProperty() { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  87 */   public int getPropertyType() { return 28; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  94 */   public String getPropertyName() { return "font-weight"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 101 */   public Value getDefaultValue() { return ValueConstants.NORMAL_VALUE; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Value createValue(LexicalUnit lu, CSSEngine engine) throws DOMException {
/* 109 */     if (lu.getLexicalUnitType() == 13) {
/* 110 */       int i = lu.getIntegerValue();
/* 111 */       switch (i) {
/*     */         case 100:
/* 113 */           return ValueConstants.NUMBER_100;
/*     */         case 200:
/* 115 */           return ValueConstants.NUMBER_200;
/*     */         case 300:
/* 117 */           return ValueConstants.NUMBER_300;
/*     */         case 400:
/* 119 */           return ValueConstants.NUMBER_400;
/*     */         case 500:
/* 121 */           return ValueConstants.NUMBER_500;
/*     */         case 600:
/* 123 */           return ValueConstants.NUMBER_600;
/*     */         case 700:
/* 125 */           return ValueConstants.NUMBER_700;
/*     */         case 800:
/* 127 */           return ValueConstants.NUMBER_800;
/*     */         case 900:
/* 129 */           return ValueConstants.NUMBER_900;
/*     */       } 
/* 131 */       throw createInvalidFloatValueDOMException(i);
/*     */     } 
/* 133 */     return super.createValue(lu, engine);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Value createFloatValue(short type, float floatValue) throws DOMException {
/* 141 */     if (type == 1) {
/* 142 */       int i = (int)floatValue;
/* 143 */       if (floatValue == i) {
/* 144 */         switch (i) {
/*     */           case 100:
/* 146 */             return ValueConstants.NUMBER_100;
/*     */           case 200:
/* 148 */             return ValueConstants.NUMBER_200;
/*     */           case 300:
/* 150 */             return ValueConstants.NUMBER_300;
/*     */           case 400:
/* 152 */             return ValueConstants.NUMBER_400;
/*     */           case 500:
/* 154 */             return ValueConstants.NUMBER_500;
/*     */           case 600:
/* 156 */             return ValueConstants.NUMBER_600;
/*     */           case 700:
/* 158 */             return ValueConstants.NUMBER_700;
/*     */           case 800:
/* 160 */             return ValueConstants.NUMBER_800;
/*     */           case 900:
/* 162 */             return ValueConstants.NUMBER_900;
/*     */         } 
/*     */       }
/*     */     } 
/* 166 */     throw createInvalidFloatValueDOMException(floatValue);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Value computeValue(CSSStylableElement elt, String pseudo, CSSEngine engine, int idx, StyleMap sm, Value value) {
/* 179 */     if (value == ValueConstants.BOLDER_VALUE) {
/* 180 */       float f; sm.putParentRelative(idx, true);
/*     */       
/* 182 */       CSSContext ctx = engine.getCSSContext();
/* 183 */       CSSStylableElement p = CSSEngine.getParentCSSStylableElement(elt);
/*     */       
/* 185 */       if (p == null) {
/* 186 */         f = 400.0F;
/*     */       } else {
/* 188 */         Value v = engine.getComputedStyle(p, pseudo, idx);
/* 189 */         f = v.getFloatValue();
/*     */       } 
/* 191 */       return createFontWeight(ctx.getBolderFontWeight(f));
/* 192 */     }  if (value == ValueConstants.LIGHTER_VALUE) {
/* 193 */       float f; sm.putParentRelative(idx, true);
/*     */       
/* 195 */       CSSContext ctx = engine.getCSSContext();
/* 196 */       CSSStylableElement p = CSSEngine.getParentCSSStylableElement(elt);
/*     */       
/* 198 */       if (p == null) {
/* 199 */         f = 400.0F;
/*     */       } else {
/* 201 */         Value v = engine.getComputedStyle(p, pseudo, idx);
/* 202 */         f = v.getFloatValue();
/*     */       } 
/* 204 */       return createFontWeight(ctx.getLighterFontWeight(f));
/* 205 */     }  if (value == ValueConstants.NORMAL_VALUE)
/* 206 */       return ValueConstants.NUMBER_400; 
/* 207 */     if (value == ValueConstants.BOLD_VALUE) {
/* 208 */       return ValueConstants.NUMBER_700;
/*     */     }
/* 210 */     return value;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Value createFontWeight(float f) {
/* 217 */     switch ((int)f) {
/*     */       case 100:
/* 219 */         return ValueConstants.NUMBER_100;
/*     */       case 200:
/* 221 */         return ValueConstants.NUMBER_200;
/*     */       case 300:
/* 223 */         return ValueConstants.NUMBER_300;
/*     */       case 400:
/* 225 */         return ValueConstants.NUMBER_400;
/*     */       case 500:
/* 227 */         return ValueConstants.NUMBER_500;
/*     */       case 600:
/* 229 */         return ValueConstants.NUMBER_600;
/*     */       case 700:
/* 231 */         return ValueConstants.NUMBER_700;
/*     */       case 800:
/* 233 */         return ValueConstants.NUMBER_800;
/*     */     } 
/* 235 */     return ValueConstants.NUMBER_900;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 243 */   public StringMap getIdentifiers() { return values; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\engine\value\css2\FontWeightManager.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */