/*     */ package org.apache.batik.css.engine.value.svg;
/*     */ 
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.CSSStylableElement;
/*     */ import org.apache.batik.css.engine.StyleMap;
/*     */ import org.apache.batik.css.engine.value.ListValue;
/*     */ import org.apache.batik.css.engine.value.Value;
/*     */ import org.apache.batik.css.engine.value.ValueConstants;
/*     */ import org.w3c.css.sac.LexicalUnit;
/*     */ import org.w3c.dom.DOMException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGColorManager
/*     */   extends ColorManager
/*     */ {
/*     */   protected String property;
/*     */   protected Value defaultValue;
/*     */   
/*  57 */   public SVGColorManager(String prop) { this(prop, ValueConstants.BLACK_RGB_VALUE); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGColorManager(String prop, Value v) {
/*  64 */     this.property = prop;
/*  65 */     this.defaultValue = v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  72 */   public boolean isInheritedProperty() { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  79 */   public boolean isAnimatableProperty() { return true; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  86 */   public boolean isAdditiveProperty() { return true; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  93 */   public int getPropertyType() { return 6; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 100 */   public String getPropertyName() { return this.property; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 109 */   public Value getDefaultValue() { return this.defaultValue; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Value createValue(LexicalUnit lu, CSSEngine engine) throws DOMException {
/* 117 */     if (lu.getLexicalUnitType() == 35 && 
/* 118 */       lu.getStringValue().equalsIgnoreCase("currentcolor"))
/*     */     {
/* 120 */       return SVGValueConstants.CURRENTCOLOR_VALUE;
/*     */     }
/*     */     
/* 123 */     Value v = super.createValue(lu, engine);
/* 124 */     lu = lu.getNextLexicalUnit();
/* 125 */     if (lu == null) {
/* 126 */       return v;
/*     */     }
/* 128 */     if (lu.getLexicalUnitType() != 41 || !lu.getFunctionName().equalsIgnoreCase("icc-color"))
/*     */     {
/* 130 */       throw createInvalidLexicalUnitDOMException(lu.getLexicalUnitType());
/*     */     }
/*     */     
/* 133 */     lu = lu.getParameters();
/* 134 */     if (lu.getLexicalUnitType() != 35) {
/* 135 */       throw createInvalidLexicalUnitDOMException(lu.getLexicalUnitType());
/*     */     }
/*     */     
/* 138 */     ListValue result = new ListValue(' ');
/* 139 */     result.append(v);
/*     */     
/* 141 */     ICCColor icc = new ICCColor(lu.getStringValue());
/* 142 */     result.append(icc);
/*     */     
/* 144 */     lu = lu.getNextLexicalUnit();
/* 145 */     while (lu != null) {
/* 146 */       if (lu.getLexicalUnitType() != 0) {
/* 147 */         throw createInvalidLexicalUnitDOMException(lu.getLexicalUnitType());
/*     */       }
/*     */       
/* 150 */       lu = lu.getNextLexicalUnit();
/* 151 */       if (lu == null) {
/* 152 */         throw createInvalidLexicalUnitDOMException((short)-1);
/*     */       }
/* 154 */       icc.append(getColorValue(lu));
/* 155 */       lu = lu.getNextLexicalUnit();
/*     */     } 
/* 157 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Value computeValue(CSSStylableElement elt, String pseudo, CSSEngine engine, int idx, StyleMap sm, Value value) {
/* 170 */     if (value == SVGValueConstants.CURRENTCOLOR_VALUE) {
/* 171 */       sm.putColorRelative(idx, true);
/*     */       
/* 173 */       int ci = engine.getColorIndex();
/* 174 */       return engine.getComputedStyle(elt, pseudo, ci);
/*     */     } 
/* 176 */     if (value.getCssValueType() == 2) {
/* 177 */       ListValue lv = (ListValue)value;
/* 178 */       Value v = lv.item(0);
/* 179 */       Value t = super.computeValue(elt, pseudo, engine, idx, sm, v);
/* 180 */       if (t != v) {
/* 181 */         ListValue result = new ListValue(' ');
/* 182 */         result.append(t);
/* 183 */         result.append(lv.item(1));
/* 184 */         return result;
/*     */       } 
/* 186 */       return value;
/*     */     } 
/* 188 */     return super.computeValue(elt, pseudo, engine, idx, sm, value);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected float getColorValue(LexicalUnit lu) {
/* 195 */     switch (lu.getLexicalUnitType()) {
/*     */       case 13:
/* 197 */         return lu.getIntegerValue();
/*     */       case 14:
/* 199 */         return lu.getFloatValue();
/*     */     } 
/* 201 */     throw createInvalidLexicalUnitDOMException(lu.getLexicalUnitType());
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\engine\value\svg\SVGColorManager.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */