/*     */ package org.apache.batik.css.parser;
/*     */ 
/*     */ import org.w3c.css.sac.LexicalUnit;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class CSSLexicalUnit
/*     */   implements LexicalUnit
/*     */ {
/*     */   public static final String UNIT_TEXT_CENTIMETER = "cm";
/*     */   public static final String UNIT_TEXT_DEGREE = "deg";
/*     */   public static final String UNIT_TEXT_EM = "em";
/*     */   public static final String UNIT_TEXT_EX = "ex";
/*     */   public static final String UNIT_TEXT_GRADIAN = "grad";
/*     */   public static final String UNIT_TEXT_HERTZ = "Hz";
/*     */   public static final String UNIT_TEXT_INCH = "in";
/*     */   public static final String UNIT_TEXT_KILOHERTZ = "kHz";
/*     */   public static final String UNIT_TEXT_MILLIMETER = "mm";
/*     */   public static final String UNIT_TEXT_MILLISECOND = "ms";
/*     */   public static final String UNIT_TEXT_PERCENTAGE = "%";
/*     */   public static final String UNIT_TEXT_PICA = "pc";
/*     */   public static final String UNIT_TEXT_PIXEL = "px";
/*     */   public static final String UNIT_TEXT_POINT = "pt";
/*     */   public static final String UNIT_TEXT_RADIAN = "rad";
/*     */   public static final String UNIT_TEXT_REAL = "";
/*     */   public static final String UNIT_TEXT_SECOND = "s";
/*     */   public static final String TEXT_RGBCOLOR = "rgb";
/*     */   public static final String TEXT_RECT_FUNCTION = "rect";
/*     */   public static final String TEXT_COUNTER_FUNCTION = "counter";
/*     */   public static final String TEXT_COUNTERS_FUNCTION = "counters";
/*     */   protected short lexicalUnitType;
/*     */   protected LexicalUnit nextLexicalUnit;
/*     */   protected LexicalUnit previousLexicalUnit;
/*     */   
/*     */   protected CSSLexicalUnit(short t, LexicalUnit prev) {
/*  73 */     this.lexicalUnitType = t;
/*  74 */     this.previousLexicalUnit = prev;
/*  75 */     if (prev != null) {
/*  76 */       ((CSSLexicalUnit)prev).nextLexicalUnit = this;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  84 */   public short getLexicalUnitType() { return this.lexicalUnitType; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  91 */   public LexicalUnit getNextLexicalUnit() { return this.nextLexicalUnit; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  98 */   public void setNextLexicalUnit(LexicalUnit lu) { this.nextLexicalUnit = lu; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 105 */   public LexicalUnit getPreviousLexicalUnit() { return this.previousLexicalUnit; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 112 */   public void setPreviousLexicalUnit(LexicalUnit lu) { this.previousLexicalUnit = lu; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 119 */   public int getIntegerValue() { throw new IllegalStateException(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 126 */   public float getFloatValue() { throw new IllegalStateException(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getDimensionUnitText() {
/* 133 */     switch (this.lexicalUnitType) { case 19:
/* 134 */         return "cm";
/* 135 */       case 28: return "deg";
/* 136 */       case 15: return "em";
/* 137 */       case 16: return "ex";
/* 138 */       case 29: return "grad";
/* 139 */       case 33: return "Hz";
/* 140 */       case 18: return "in";
/* 141 */       case 34: return "kHz";
/* 142 */       case 20: return "mm";
/* 143 */       case 31: return "ms";
/* 144 */       case 23: return "%";
/* 145 */       case 22: return "pc";
/* 146 */       case 17: return "px";
/* 147 */       case 21: return "pt";
/* 148 */       case 30: return "rad";
/* 149 */       case 14: return "";
/* 150 */       case 32: return "s"; }
/*     */     
/* 152 */     throw new IllegalStateException("No Unit Text for type: " + this.lexicalUnitType);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 161 */   public String getFunctionName() { throw new IllegalStateException(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 168 */   public LexicalUnit getParameters() { throw new IllegalStateException(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 175 */   public String getStringValue() { throw new IllegalStateException(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 182 */   public LexicalUnit getSubValues() { throw new IllegalStateException(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 189 */   public static CSSLexicalUnit createSimple(short t, LexicalUnit prev) { return new SimpleLexicalUnit(t, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class SimpleLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/* 201 */     public SimpleLexicalUnit(short t, LexicalUnit prev) { super(t, prev); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 209 */   public static CSSLexicalUnit createInteger(int val, LexicalUnit prev) { return new IntegerLexicalUnit(val, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class IntegerLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/*     */     protected int value;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public IntegerLexicalUnit(int val, LexicalUnit prev) {
/* 226 */       super((short)13, prev);
/* 227 */       this.value = val;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 234 */     public int getIntegerValue() { return this.value; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 242 */   public static CSSLexicalUnit createFloat(short t, float val, LexicalUnit prev) { return new FloatLexicalUnit(t, val, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class FloatLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/*     */     protected float value;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public FloatLexicalUnit(short t, float val, LexicalUnit prev) {
/* 259 */       super(t, prev);
/* 260 */       this.value = val;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 267 */     public float getFloatValue() { return this.value; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 276 */   public static CSSLexicalUnit createDimension(float val, String dim, LexicalUnit prev) { return new DimensionLexicalUnit(val, dim, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class DimensionLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/*     */     protected float value;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String dimension;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public DimensionLexicalUnit(float val, String dim, LexicalUnit prev) {
/* 298 */       super((short)42, prev);
/* 299 */       this.value = val;
/* 300 */       this.dimension = dim;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 307 */     public float getFloatValue() { return this.value; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 314 */     public String getDimensionUnitText() { return this.dimension; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 323 */   public static CSSLexicalUnit createFunction(String f, LexicalUnit params, LexicalUnit prev) { return new FunctionLexicalUnit(f, params, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class FunctionLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/*     */     protected String name;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected LexicalUnit parameters;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public FunctionLexicalUnit(String f, LexicalUnit params, LexicalUnit prev) {
/* 345 */       super((short)41, prev);
/* 346 */       this.name = f;
/* 347 */       this.parameters = params;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 354 */     public String getFunctionName() { return this.name; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 361 */     public LexicalUnit getParameters() { return this.parameters; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 371 */   public static CSSLexicalUnit createPredefinedFunction(short t, LexicalUnit params, LexicalUnit prev) { return new PredefinedFunctionLexicalUnit(t, params, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class PredefinedFunctionLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/*     */     protected LexicalUnit parameters;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public PredefinedFunctionLexicalUnit(short t, LexicalUnit params, LexicalUnit prev) {
/* 389 */       super(t, prev);
/* 390 */       this.parameters = params;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/*     */     public String getFunctionName() {
/* 396 */       switch (this.lexicalUnitType) { case 27:
/* 397 */           return "rgb";
/* 398 */         case 38: return "rect";
/* 399 */         case 25: return "counter";
/* 400 */         case 26: return "counters"; }
/*     */ 
/*     */       
/* 403 */       return super.getFunctionName();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 411 */     public LexicalUnit getParameters() { return this.parameters; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 419 */   public static CSSLexicalUnit createString(short t, String val, LexicalUnit prev) { return new StringLexicalUnit(t, val, prev); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class StringLexicalUnit
/*     */     extends CSSLexicalUnit
/*     */   {
/*     */     protected String value;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public StringLexicalUnit(short t, String val, LexicalUnit prev) {
/* 436 */       super(t, prev);
/* 437 */       this.value = val;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 444 */     public String getStringValue() { return this.value; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\parser\CSSLexicalUnit.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */