/*      */ package org.apache.batik.css.parser;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import java.util.Locale;
/*      */ import java.util.MissingResourceException;
/*      */ import java.util.StringTokenizer;
/*      */ import org.apache.batik.i18n.Localizable;
/*      */ import org.apache.batik.i18n.LocalizableSupport;
/*      */ import org.apache.batik.util.ParsedURL;
/*      */ import org.w3c.css.sac.AttributeCondition;
/*      */ import org.w3c.css.sac.CSSException;
/*      */ import org.w3c.css.sac.CSSParseException;
/*      */ import org.w3c.css.sac.CombinatorCondition;
/*      */ import org.w3c.css.sac.Condition;
/*      */ import org.w3c.css.sac.ConditionFactory;
/*      */ import org.w3c.css.sac.ConditionalSelector;
/*      */ import org.w3c.css.sac.DescendantSelector;
/*      */ import org.w3c.css.sac.DocumentHandler;
/*      */ import org.w3c.css.sac.ErrorHandler;
/*      */ import org.w3c.css.sac.InputSource;
/*      */ import org.w3c.css.sac.LangCondition;
/*      */ import org.w3c.css.sac.LexicalUnit;
/*      */ import org.w3c.css.sac.SACMediaList;
/*      */ import org.w3c.css.sac.Selector;
/*      */ import org.w3c.css.sac.SelectorFactory;
/*      */ import org.w3c.css.sac.SelectorList;
/*      */ import org.w3c.css.sac.SiblingSelector;
/*      */ import org.w3c.css.sac.SimpleSelector;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class Parser
/*      */   implements ExtendedParser, Localizable
/*      */ {
/*      */   public static final String BUNDLE_CLASSNAME = "org.apache.batik.css.parser.resources.Messages";
/*   63 */   protected LocalizableSupport localizableSupport = new LocalizableSupport("org.apache.batik.css.parser.resources.Messages", Parser.class.getClassLoader());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Scanner scanner;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int current;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   80 */   protected DocumentHandler documentHandler = DefaultDocumentHandler.INSTANCE;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   86 */   protected SelectorFactory selectorFactory = DefaultSelectorFactory.INSTANCE;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   92 */   protected ConditionFactory conditionFactory = DefaultConditionFactory.INSTANCE;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   98 */   protected ErrorHandler errorHandler = DefaultErrorHandler.INSTANCE;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String pseudoElement;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String documentURI;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  116 */   public String getParserVersion() { return "http://www.w3.org/TR/REC-CSS2"; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  123 */   public void setLocale(Locale locale) throws CSSException { this.localizableSupport.setLocale(locale); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  130 */   public Locale getLocale() { return this.localizableSupport.getLocale(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  139 */   public String formatMessage(String key, Object[] args) throws MissingResourceException { return this.localizableSupport.formatMessage(key, args); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  147 */   public void setDocumentHandler(DocumentHandler handler) { this.documentHandler = handler; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  155 */   public void setSelectorFactory(SelectorFactory factory) { this.selectorFactory = factory; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  163 */   public void setConditionFactory(ConditionFactory factory) { this.conditionFactory = factory; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  171 */   public void setErrorHandler(ErrorHandler handler) { this.errorHandler = handler; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseStyleSheet(InputSource source) throws CSSException, IOException {
/*  180 */     this.scanner = createScanner(source);
/*      */     
/*      */     try {
/*  183 */       this.documentHandler.startDocument(source);
/*      */       
/*  185 */       this.current = this.scanner.next();
/*  186 */       switch (this.current) {
/*      */         case 30:
/*  188 */           if (nextIgnoreSpaces() != 19) {
/*  189 */             reportError("charset.string"); break;
/*      */           } 
/*  191 */           if (nextIgnoreSpaces() != 8) {
/*  192 */             reportError("semicolon");
/*      */           }
/*  194 */           next();
/*      */           break;
/*      */         
/*      */         case 18:
/*  198 */           this.documentHandler.comment(this.scanner.getStringValue());
/*      */           break;
/*      */       } 
/*  201 */       skipSpacesAndCDOCDC();
/*      */       
/*  203 */       while (this.current == 28) {
/*  204 */         nextIgnoreSpaces();
/*  205 */         parseImportRule();
/*  206 */         nextIgnoreSpaces();
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       while (true) {
/*  213 */         switch (this.current) {
/*      */           case 33:
/*  215 */             nextIgnoreSpaces();
/*  216 */             parsePageRule();
/*      */             break;
/*      */           case 32:
/*  219 */             nextIgnoreSpaces();
/*  220 */             parseMediaRule();
/*      */             break;
/*      */           case 31:
/*  223 */             nextIgnoreSpaces();
/*  224 */             parseFontFaceRule();
/*      */             break;
/*      */           case 29:
/*  227 */             nextIgnoreSpaces();
/*  228 */             parseAtRule();
/*      */             break;
/*      */           case 0:
/*      */             break;
/*      */           default:
/*  233 */             parseRuleSet(); break;
/*      */         } 
/*  235 */         skipSpacesAndCDOCDC();
/*      */       } 
/*      */     } finally {
/*  238 */       this.documentHandler.endDocument(source);
/*  239 */       this.scanner = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  248 */   public void parseStyleSheet(String uri) throws CSSException, IOException { parseStyleSheet(new InputSource(uri)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseStyleDeclaration(InputSource source) throws CSSException, IOException {
/*  258 */     this.scanner = createScanner(source);
/*  259 */     parseStyleDeclarationInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseStyleDeclarationInternal() {
/*  267 */     nextIgnoreSpaces();
/*      */     try {
/*  269 */       parseStyleDeclaration(false);
/*      */     } catch (CSSParseException e) {
/*  271 */       reportError(e);
/*      */     } finally {
/*  273 */       this.scanner = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseRule(InputSource source) throws CSSException, IOException {
/*  283 */     this.scanner = createScanner(source);
/*  284 */     parseRuleInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseRuleInternal() {
/*  291 */     nextIgnoreSpaces();
/*  292 */     parseRule();
/*  293 */     this.scanner = null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public SelectorList parseSelectors(InputSource source) throws CSSException, IOException {
/*  302 */     this.scanner = createScanner(source);
/*  303 */     return parseSelectorsInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected SelectorList parseSelectorsInternal() throws CSSException, IOException {
/*  311 */     nextIgnoreSpaces();
/*  312 */     SelectorList ret = parseSelectorList();
/*  313 */     this.scanner = null;
/*  314 */     return ret;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public LexicalUnit parsePropertyValue(InputSource source) throws CSSException, IOException {
/*  323 */     this.scanner = createScanner(source);
/*  324 */     return parsePropertyValueInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected LexicalUnit parsePropertyValueInternal() throws CSSException, IOException {
/*  332 */     nextIgnoreSpaces();
/*      */     
/*  334 */     LexicalUnit exp = null;
/*      */     
/*      */     try {
/*  337 */       exp = parseExpression(false);
/*      */     } catch (CSSParseException e) {
/*  339 */       reportError(e);
/*  340 */       throw e;
/*      */     } 
/*      */     
/*  343 */     CSSParseException exception = null;
/*  344 */     if (this.current != 0) {
/*  345 */       exception = createCSSParseException("eof.expected");
/*      */     }
/*  347 */     this.scanner = null;
/*      */     
/*  349 */     if (exception != null) {
/*  350 */       this.errorHandler.fatalError(exception);
/*      */     }
/*  352 */     return exp;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean parsePriority(InputSource source) throws CSSException, IOException {
/*  361 */     this.scanner = createScanner(source);
/*  362 */     return parsePriorityInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean parsePriorityInternal() throws CSSException, IOException {
/*  370 */     nextIgnoreSpaces();
/*      */     
/*  372 */     this.scanner = null;
/*      */     
/*  374 */     switch (this.current) {
/*      */       case 0:
/*  376 */         return false;
/*      */       case 28:
/*  378 */         return true;
/*      */     } 
/*  380 */     reportError("token", new Object[] { new Integer(this.current) });
/*  381 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseRule() {
/*  389 */     switch (this.scanner.getType()) {
/*      */       case 28:
/*  391 */         nextIgnoreSpaces();
/*  392 */         parseImportRule();
/*      */         return;
/*      */       case 29:
/*  395 */         nextIgnoreSpaces();
/*  396 */         parseAtRule();
/*      */         return;
/*      */       case 31:
/*  399 */         nextIgnoreSpaces();
/*  400 */         parseFontFaceRule();
/*      */         return;
/*      */       case 32:
/*  403 */         nextIgnoreSpaces();
/*  404 */         parseMediaRule();
/*      */         return;
/*      */       case 33:
/*  407 */         nextIgnoreSpaces();
/*  408 */         parsePageRule();
/*      */         return;
/*      */     } 
/*  411 */     parseRuleSet();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseAtRule() {
/*  419 */     this.scanner.scanAtRule();
/*  420 */     this.documentHandler.ignorableAtRule(this.scanner.getStringValue());
/*  421 */     nextIgnoreSpaces();
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseImportRule() {
/*      */     CSSSACMediaList cSSSACMediaList;
/*  428 */     String uri = null;
/*  429 */     switch (this.current) {
/*      */       default:
/*  431 */         reportError("string.or.uri"); return;
/*      */       case 19:
/*      */       case 51:
/*      */         break;
/*  435 */     }  uri = this.scanner.getStringValue();
/*  436 */     nextIgnoreSpaces();
/*      */ 
/*      */ 
/*      */     
/*  440 */     if (this.current != 20) {
/*  441 */       cSSSACMediaList = new CSSSACMediaList();
/*  442 */       cSSSACMediaList.append("all");
/*      */     } else {
/*  444 */       cSSSACMediaList = parseMediaList();
/*      */     } 
/*      */     
/*  447 */     this.documentHandler.importStyle(uri, cSSSACMediaList, null);
/*      */     
/*  449 */     if (this.current != 8) {
/*  450 */       reportError("semicolon");
/*      */     } else {
/*  452 */       next();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected CSSSACMediaList parseMediaList() {
/*  460 */     CSSSACMediaList result = new CSSSACMediaList();
/*  461 */     result.append(this.scanner.getStringValue());
/*  462 */     nextIgnoreSpaces();
/*      */     
/*  464 */     while (this.current == 6) {
/*  465 */       nextIgnoreSpaces();
/*      */       
/*  467 */       switch (this.current) {
/*      */ 
/*      */ 
/*      */         
/*      */         case 20:
/*  472 */           result.append(this.scanner.getStringValue());
/*  473 */           nextIgnoreSpaces(); break;
/*      */       } 
/*      */     } 
/*  476 */     return result;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseFontFaceRule() {
/*      */     try {
/*  484 */       this.documentHandler.startFontFace();
/*      */       
/*  486 */       if (this.current != 1) {
/*  487 */         reportError("left.curly.brace");
/*      */       } else {
/*  489 */         nextIgnoreSpaces();
/*      */         
/*      */         try {
/*  492 */           parseStyleDeclaration(true);
/*      */         } catch (CSSParseException e) {
/*  494 */           reportError(e);
/*      */         } 
/*      */       } 
/*      */     } finally {
/*  498 */       this.documentHandler.endFontFace();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parsePageRule() {
/*  506 */     String page = null;
/*  507 */     String ppage = null;
/*      */     
/*  509 */     if (this.current == 20) {
/*  510 */       page = this.scanner.getStringValue();
/*  511 */       nextIgnoreSpaces();
/*      */       
/*  513 */       if (this.current == 16) {
/*  514 */         nextIgnoreSpaces();
/*      */         
/*  516 */         if (this.current != 20) {
/*  517 */           reportError("identifier");
/*      */           return;
/*      */         } 
/*  520 */         ppage = this.scanner.getStringValue();
/*  521 */         nextIgnoreSpaces();
/*      */       } 
/*      */     } 
/*      */     
/*      */     try {
/*  526 */       this.documentHandler.startPage(page, ppage);
/*      */       
/*  528 */       if (this.current != 1) {
/*  529 */         reportError("left.curly.brace");
/*      */       } else {
/*  531 */         nextIgnoreSpaces();
/*      */         
/*      */         try {
/*  534 */           parseStyleDeclaration(true);
/*      */         } catch (CSSParseException e) {
/*  536 */           reportError(e);
/*      */         } 
/*      */       } 
/*      */     } finally {
/*  540 */       this.documentHandler.endPage(page, ppage);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseMediaRule() {
/*  548 */     if (this.current != 20) {
/*  549 */       reportError("identifier");
/*      */       
/*      */       return;
/*      */     } 
/*  553 */     CSSSACMediaList ml = parseMediaList();
/*      */     try {
/*  555 */       this.documentHandler.startMedia(ml);
/*      */       
/*  557 */       if (this.current != 1) {
/*  558 */         reportError("left.curly.brace");
/*      */       } else {
/*  560 */         nextIgnoreSpaces();
/*      */         
/*      */         while (true) {
/*  563 */           switch (this.current) {
/*      */             case 0:
/*      */             case 2:
/*      */               break;
/*      */           } 
/*  568 */           parseRuleSet();
/*      */         } 
/*      */ 
/*      */         
/*  572 */         nextIgnoreSpaces();
/*      */       } 
/*      */     } finally {
/*  575 */       this.documentHandler.endMedia(ml);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseRuleSet() {
/*  583 */     SelectorList sl = null;
/*      */     
/*      */     try {
/*  586 */       sl = parseSelectorList();
/*      */     } catch (CSSParseException e) {
/*  588 */       reportError(e);
/*      */       
/*      */       return;
/*      */     } 
/*      */     try {
/*  593 */       this.documentHandler.startSelector(sl);
/*      */       
/*  595 */       if (this.current != 1) {
/*  596 */         reportError("left.curly.brace");
/*  597 */         if (this.current == 2) {
/*  598 */           nextIgnoreSpaces();
/*      */         }
/*      */       } else {
/*  601 */         nextIgnoreSpaces();
/*      */         
/*      */         try {
/*  604 */           parseStyleDeclaration(true);
/*      */         } catch (CSSParseException e) {
/*  606 */           reportError(e);
/*      */         } 
/*      */       } 
/*      */     } finally {
/*  610 */       this.documentHandler.endSelector(sl);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected SelectorList parseSelectorList() throws CSSException, IOException {
/*  618 */     CSSSelectorList result = new CSSSelectorList();
/*  619 */     result.append(parseSelector());
/*      */     
/*      */     while (true) {
/*  622 */       if (this.current != 6) {
/*  623 */         return result;
/*      */       }
/*  625 */       nextIgnoreSpaces();
/*  626 */       result.append(parseSelector());
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Selector parseSelector() {
/*  634 */     this.pseudoElement = null;
/*  635 */     DescendantSelector descendantSelector = parseSimpleSelector(); while (true) {
/*      */       DescendantSelector descendantSelector1;
/*      */       SiblingSelector siblingSelector;
/*  638 */       switch (this.current) {
/*      */         default:
/*      */           break;
/*      */         case 7:
/*      */         case 11:
/*      */         case 13:
/*      */         case 16:
/*      */         case 20:
/*      */         case 27:
/*  647 */           if (this.pseudoElement != null) {
/*  648 */             throw createCSSParseException("pseudo.element.position");
/*      */           }
/*  650 */           descendantSelector1 = this.selectorFactory.createDescendantSelector(descendantSelector, parseSimpleSelector());
/*      */           continue;
/*      */ 
/*      */         
/*      */         case 4:
/*  655 */           if (this.pseudoElement != null) {
/*  656 */             throw createCSSParseException("pseudo.element.position");
/*      */           }
/*  658 */           nextIgnoreSpaces();
/*  659 */           siblingSelector = this.selectorFactory.createDirectAdjacentSelector((short)1, descendantSelector1, parseSimpleSelector());
/*      */           continue;
/*      */         
/*      */         case 9:
/*      */           break;
/*      */       } 
/*  665 */       if (this.pseudoElement != null) {
/*  666 */         throw createCSSParseException("pseudo.element.position");
/*      */       }
/*  668 */       nextIgnoreSpaces();
/*  669 */       descendantSelector = this.selectorFactory.createChildSelector(siblingSelector, parseSimpleSelector());
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  674 */     if (this.pseudoElement != null) {
/*  675 */       descendantSelector = this.selectorFactory.createChildSelector(descendantSelector, this.selectorFactory.createPseudoElementSelector(null, this.pseudoElement));
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  680 */     return descendantSelector;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected SimpleSelector parseSimpleSelector() {
/*      */     ConditionalSelector conditionalSelector;
/*  689 */     switch (this.current) {
/*      */       case 20:
/*  691 */         conditionalSelector = this.selectorFactory.createElementSelector(null, this.scanner.getStringValue());
/*      */         
/*  693 */         next();
/*      */         break;
/*      */       case 13:
/*  696 */         next();
/*      */       default:
/*  698 */         conditionalSelector = this.selectorFactory.createElementSelector(null, null); break;
/*      */     } 
/*  700 */     CombinatorCondition combinatorCondition = null; while (true) {
/*      */       String lang, func, val, val; int op; String name; AttributeCondition attributeCondition; LangCondition langCondition;
/*  702 */       Condition c = null;
/*  703 */       switch (this.current) {
/*      */         case 27:
/*  705 */           attributeCondition = this.conditionFactory.createIdCondition(this.scanner.getStringValue());
/*      */           
/*  707 */           next();
/*      */           break;
/*      */         case 7:
/*  710 */           if (next() != 20) {
/*  711 */             throw createCSSParseException("identifier");
/*      */           }
/*  713 */           attributeCondition = this.conditionFactory.createClassCondition(null, this.scanner.getStringValue());
/*      */           
/*  715 */           next();
/*      */           break;
/*      */         case 11:
/*  718 */           if (nextIgnoreSpaces() != 20) {
/*  719 */             throw createCSSParseException("identifier");
/*      */           }
/*  721 */           name = this.scanner.getStringValue();
/*  722 */           op = nextIgnoreSpaces();
/*  723 */           switch (op) {
/*      */             default:
/*  725 */               throw createCSSParseException("right.bracket");
/*      */             case 12:
/*  727 */               nextIgnoreSpaces();
/*  728 */               attributeCondition = this.conditionFactory.createAttributeCondition(name, null, false, null); break;
/*      */             case 3:
/*      */             case 25:
/*      */             case 26:
/*      */               break;
/*      */           } 
/*  734 */           val = null;
/*  735 */           switch (nextIgnoreSpaces())
/*      */           { default:
/*  737 */               throw createCSSParseException("identifier.or.string");
/*      */             case 19:
/*      */             case 20:
/*  740 */               break; }  val = this.scanner.getStringValue();
/*  741 */           nextIgnoreSpaces();
/*      */           
/*  743 */           if (this.current != 12) {
/*  744 */             throw createCSSParseException("right.bracket");
/*      */           }
/*  746 */           next();
/*  747 */           switch (op) {
/*      */             case 3:
/*  749 */               attributeCondition = this.conditionFactory.createAttributeCondition(name, null, false, val);
/*      */               break;
/*      */             
/*      */             case 26:
/*  753 */               attributeCondition = this.conditionFactory.createOneOfAttributeCondition(name, null, false, val);
/*      */               break;
/*      */           } 
/*      */           
/*  757 */           attributeCondition = this.conditionFactory.createBeginHyphenAttributeCondition(name, null, false, val);
/*      */           break;
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*      */         case 16:
/*  764 */           switch (nextIgnoreSpaces()) {
/*      */             case 20:
/*  766 */               val = this.scanner.getStringValue();
/*  767 */               if (isPseudoElement(val)) {
/*  768 */                 if (this.pseudoElement != null) {
/*  769 */                   throw createCSSParseException("duplicate.pseudo.element");
/*      */                 }
/*      */                 
/*  772 */                 this.pseudoElement = val;
/*      */               } else {
/*  774 */                 attributeCondition = this.conditionFactory.createPseudoClassCondition(null, val);
/*      */               } 
/*      */               
/*  777 */               next();
/*      */               break;
/*      */             case 52:
/*  780 */               func = this.scanner.getStringValue();
/*  781 */               if (nextIgnoreSpaces() != 20) {
/*  782 */                 throw createCSSParseException("identifier");
/*      */               }
/*  784 */               lang = this.scanner.getStringValue();
/*  785 */               if (nextIgnoreSpaces() != 15) {
/*  786 */                 throw createCSSParseException("right.brace");
/*      */               }
/*      */               
/*  789 */               if (!func.equalsIgnoreCase("lang")) {
/*  790 */                 throw createCSSParseException("pseudo.function");
/*      */               }
/*      */               
/*  793 */               langCondition = this.conditionFactory.createLangCondition(lang);
/*      */               
/*  795 */               next();
/*      */               break;
/*      */           } 
/*  798 */           throw createCSSParseException("identifier");
/*      */         
/*      */         default:
/*      */           break;
/*      */       } 
/*      */       
/*  804 */       if (langCondition != null) {
/*  805 */         LangCondition langCondition1; if (combinatorCondition == null) {
/*  806 */           langCondition1 = langCondition; continue;
/*      */         } 
/*  808 */         combinatorCondition = this.conditionFactory.createAndCondition(langCondition1, langCondition);
/*      */       } 
/*      */     } 
/*      */     
/*  812 */     skipSpaces();
/*  813 */     if (combinatorCondition != null) {
/*  814 */       conditionalSelector = this.selectorFactory.createConditionalSelector(conditionalSelector, combinatorCondition);
/*      */     }
/*  816 */     return conditionalSelector;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean isPseudoElement(String s) {
/*  823 */     switch (s.charAt(0)) {
/*      */       case 'A':
/*      */       case 'a':
/*  826 */         return s.equalsIgnoreCase("after");
/*      */       case 'B':
/*      */       case 'b':
/*  829 */         return s.equalsIgnoreCase("before");
/*      */       case 'F':
/*      */       case 'f':
/*  832 */         return (s.equalsIgnoreCase("first-letter") || s.equalsIgnoreCase("first-line"));
/*      */     } 
/*      */     
/*  835 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseStyleDeclaration(boolean inSheet) throws CSSException {
/*      */     while (true) {
/*      */       LexicalUnit exp;
/*      */       String name;
/*  844 */       switch (this.current) {
/*      */         case 0:
/*  846 */           if (inSheet) {
/*  847 */             throw createCSSParseException("eof");
/*      */           }
/*      */           return;
/*      */         case 2:
/*  851 */           if (!inSheet) {
/*  852 */             throw createCSSParseException("eof.expected");
/*      */           }
/*  854 */           nextIgnoreSpaces();
/*      */           return;
/*      */         case 8:
/*  857 */           nextIgnoreSpaces();
/*      */           break;
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*      */         case 20:
/*  864 */           name = this.scanner.getStringValue();
/*      */           
/*  866 */           if (nextIgnoreSpaces() != 16) {
/*  867 */             throw createCSSParseException("colon");
/*      */           }
/*  869 */           nextIgnoreSpaces();
/*      */           
/*  871 */           exp = null;
/*      */           
/*      */           try {
/*  874 */             exp = parseExpression(false);
/*      */           } catch (CSSParseException e) {
/*  876 */             reportError(e);
/*      */           } 
/*      */           
/*  879 */           if (exp != null) {
/*  880 */             boolean important = false;
/*  881 */             if (this.current == 23) {
/*  882 */               important = true;
/*  883 */               nextIgnoreSpaces();
/*      */             } 
/*  885 */             this.documentHandler.property(name, exp, important);
/*      */           } 
/*      */           break;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   protected LexicalUnit parseExpression(boolean param) {
/*  895 */     LexicalUnit result = parseTerm(null);
/*  896 */     LexicalUnit curr = result;
/*      */     
/*      */     while (true) {
/*  899 */       boolean op = false;
/*  900 */       switch (this.current) {
/*      */         case 6:
/*  902 */           op = true;
/*  903 */           curr = CSSLexicalUnit.createSimple((short)0, curr);
/*      */           
/*  905 */           nextIgnoreSpaces();
/*      */           break;
/*      */         case 10:
/*  908 */           op = true;
/*  909 */           curr = CSSLexicalUnit.createSimple((short)4, curr);
/*      */           
/*  911 */           nextIgnoreSpaces(); break;
/*      */       } 
/*  913 */       if (param) {
/*  914 */         if (this.current == 15) {
/*  915 */           if (op) {
/*  916 */             throw createCSSParseException("token", new Object[] { new Integer(this.current) });
/*      */           }
/*      */           
/*  919 */           return result;
/*      */         } 
/*  921 */         curr = parseTerm(curr); continue;
/*      */       } 
/*  923 */       switch (this.current) {
/*      */         case 0:
/*      */         case 2:
/*      */         case 8:
/*      */         case 23:
/*  928 */           if (op) {
/*  929 */             throw createCSSParseException("token", new Object[] { new Integer(this.current) });
/*      */           }
/*      */           
/*  932 */           return result;
/*      */       } 
/*  934 */       curr = parseTerm(curr);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   protected LexicalUnit parseTerm(LexicalUnit prev) {
/*      */     String val;
/*      */     long lVal;
/*      */     String sval;
/*  944 */     boolean plus = true;
/*  945 */     boolean sgn = false;
/*      */     
/*  947 */     switch (this.current) {
/*      */       case 5:
/*  949 */         plus = false;
/*      */       case 4:
/*  951 */         next();
/*  952 */         sgn = true; break;
/*      */     } 
/*  954 */     switch (this.current) {
/*      */       case 24:
/*  956 */         sval = this.scanner.getStringValue();
/*  957 */         if (!plus) sval = "-" + sval;
/*      */         
/*  959 */         lVal = Long.parseLong(sval);
/*  960 */         if (lVal >= -2147483648L && lVal <= 2147483647L) {
/*      */           
/*  962 */           int iVal = (int)lVal;
/*  963 */           nextIgnoreSpaces();
/*  964 */           return CSSLexicalUnit.createInteger(iVal, prev);
/*      */         } 
/*      */ 
/*      */ 
/*      */       
/*      */       case 54:
/*  970 */         return CSSLexicalUnit.createFloat((short)14, number(plus), prev);
/*      */       
/*      */       case 42:
/*  973 */         return CSSLexicalUnit.createFloat((short)23, number(plus), prev);
/*      */       
/*      */       case 45:
/*  976 */         return CSSLexicalUnit.createFloat((short)21, number(plus), prev);
/*      */       
/*      */       case 44:
/*  979 */         return CSSLexicalUnit.createFloat((short)22, number(plus), prev);
/*      */       
/*      */       case 46:
/*  982 */         return CSSLexicalUnit.createFloat((short)17, number(plus), prev);
/*      */       
/*      */       case 37:
/*  985 */         return CSSLexicalUnit.createFloat((short)19, number(plus), prev);
/*      */       
/*      */       case 38:
/*  988 */         return CSSLexicalUnit.createFloat((short)20, number(plus), prev);
/*      */       
/*      */       case 39:
/*  991 */         return CSSLexicalUnit.createFloat((short)18, number(plus), prev);
/*      */       
/*      */       case 36:
/*  994 */         return CSSLexicalUnit.createFloat((short)15, number(plus), prev);
/*      */       
/*      */       case 35:
/*  997 */         return CSSLexicalUnit.createFloat((short)16, number(plus), prev);
/*      */       
/*      */       case 47:
/* 1000 */         return CSSLexicalUnit.createFloat((short)28, number(plus), prev);
/*      */       
/*      */       case 48:
/* 1003 */         return CSSLexicalUnit.createFloat((short)30, number(plus), prev);
/*      */       
/*      */       case 49:
/* 1006 */         return CSSLexicalUnit.createFloat((short)29, number(plus), prev);
/*      */       
/*      */       case 43:
/* 1009 */         return CSSLexicalUnit.createFloat((short)32, number(plus), prev);
/*      */       
/*      */       case 40:
/* 1012 */         return CSSLexicalUnit.createFloat((short)31, number(plus), prev);
/*      */       
/*      */       case 41:
/* 1015 */         return CSSLexicalUnit.createFloat((short)33, number(plus), prev);
/*      */       
/*      */       case 50:
/* 1018 */         return CSSLexicalUnit.createFloat((short)34, number(plus), prev);
/*      */       
/*      */       case 34:
/* 1021 */         return dimension(plus, prev);
/*      */       case 52:
/* 1023 */         return parseFunction(plus, prev);
/*      */     } 
/* 1025 */     if (sgn) {
/* 1026 */       throw createCSSParseException("token", new Object[] { new Integer(this.current) });
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1031 */     switch (this.current) {
/*      */       case 19:
/* 1033 */         val = this.scanner.getStringValue();
/* 1034 */         nextIgnoreSpaces();
/* 1035 */         return CSSLexicalUnit.createString((short)36, val, prev);
/*      */       
/*      */       case 20:
/* 1038 */         val = this.scanner.getStringValue();
/* 1039 */         nextIgnoreSpaces();
/* 1040 */         if (val.equalsIgnoreCase("inherit")) {
/* 1041 */           return CSSLexicalUnit.createSimple((short)12, prev);
/*      */         }
/*      */         
/* 1044 */         return CSSLexicalUnit.createString((short)35, val, prev);
/*      */ 
/*      */       
/*      */       case 51:
/* 1048 */         val = this.scanner.getStringValue();
/* 1049 */         nextIgnoreSpaces();
/* 1050 */         return CSSLexicalUnit.createString((short)24, val, prev);
/*      */       
/*      */       case 27:
/* 1053 */         return hexcolor(prev);
/*      */     } 
/* 1055 */     throw createCSSParseException("token", new Object[] { new Integer(this.current) });
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected LexicalUnit parseFunction(boolean positive, LexicalUnit prev) {
/* 1065 */     String name = this.scanner.getStringValue();
/* 1066 */     nextIgnoreSpaces();
/*      */     
/* 1068 */     LexicalUnit params = parseExpression(true);
/*      */     
/* 1070 */     if (this.current != 15) {
/* 1071 */       throw createCSSParseException("token", new Object[] { new Integer(this.current) });
/*      */     }
/*      */ 
/*      */     
/* 1075 */     nextIgnoreSpaces();
/*      */     
/* 1077 */     switch (name.charAt(0)) {
/*      */       
/*      */       case 'R':
/*      */       case 'r':
/* 1081 */         if (name.equalsIgnoreCase("rgb")) {
/* 1082 */           LexicalUnit lu = params;
/* 1083 */           if (lu == null) {
/*      */             break;
/*      */           }
/* 1086 */           switch (lu.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 13:
/*      */             case 23:
/*      */               break; }
/* 1091 */            lu = lu.getNextLexicalUnit();
/*      */           
/* 1093 */           if (lu == null) {
/*      */             break;
/*      */           }
/* 1096 */           switch (lu.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1100 */            lu = lu.getNextLexicalUnit();
/*      */           
/* 1102 */           if (lu == null) {
/*      */             break;
/*      */           }
/* 1105 */           switch (lu.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 13:
/*      */             case 23:
/*      */               break; }
/* 1110 */            lu = lu.getNextLexicalUnit();
/*      */           
/* 1112 */           if (lu == null) {
/*      */             break;
/*      */           }
/* 1115 */           switch (lu.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1119 */            lu = lu.getNextLexicalUnit();
/*      */           
/* 1121 */           if (lu == null) {
/*      */             break;
/*      */           }
/* 1124 */           switch (lu.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 13:
/*      */             case 23:
/*      */               break; }
/* 1129 */            lu = lu.getNextLexicalUnit();
/*      */           
/* 1131 */           if (lu != null) {
/*      */             break;
/*      */           }
/* 1134 */           return CSSLexicalUnit.createPredefinedFunction((short)27, params, prev);
/*      */         } 
/* 1136 */         if (name.equalsIgnoreCase("rect")) {
/* 1137 */           LexicalUnit lexicalUnit = params;
/* 1138 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1141 */           switch (lexicalUnit.getLexicalUnitType()) {
/*      */             default:
/*      */               break;
/*      */             case 13:
/* 1145 */               if (lexicalUnit.getIntegerValue() != 0) {
/*      */                 break;
/*      */               }
/* 1148 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 35:
/* 1151 */               if (!lexicalUnit.getStringValue().equalsIgnoreCase("auto")) {
/*      */                 break;
/*      */               }
/* 1154 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 15:
/*      */             case 16:
/*      */             case 17:
/*      */             case 18:
/*      */             case 19:
/*      */             case 20:
/*      */             case 21:
/*      */             case 22:
/*      */             case 23:
/* 1165 */               lexicalUnit = lexicalUnit.getNextLexicalUnit(); break;
/*      */           } 
/* 1167 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1170 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1174 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1176 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1179 */           switch (lexicalUnit.getLexicalUnitType()) {
/*      */             default:
/*      */               break;
/*      */             case 13:
/* 1183 */               if (lexicalUnit.getIntegerValue() != 0) {
/*      */                 break;
/*      */               }
/* 1186 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 35:
/* 1189 */               if (!lexicalUnit.getStringValue().equalsIgnoreCase("auto")) {
/*      */                 break;
/*      */               }
/* 1192 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 15:
/*      */             case 16:
/*      */             case 17:
/*      */             case 18:
/*      */             case 19:
/*      */             case 20:
/*      */             case 21:
/*      */             case 22:
/*      */             case 23:
/* 1203 */               lexicalUnit = lexicalUnit.getNextLexicalUnit(); break;
/*      */           } 
/* 1205 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1208 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1212 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1214 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1217 */           switch (lexicalUnit.getLexicalUnitType()) {
/*      */             default:
/*      */               break;
/*      */             case 13:
/* 1221 */               if (lexicalUnit.getIntegerValue() != 0) {
/*      */                 break;
/*      */               }
/* 1224 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 35:
/* 1227 */               if (!lexicalUnit.getStringValue().equalsIgnoreCase("auto")) {
/*      */                 break;
/*      */               }
/* 1230 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 15:
/*      */             case 16:
/*      */             case 17:
/*      */             case 18:
/*      */             case 19:
/*      */             case 20:
/*      */             case 21:
/*      */             case 22:
/*      */             case 23:
/* 1241 */               lexicalUnit = lexicalUnit.getNextLexicalUnit(); break;
/*      */           } 
/* 1243 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1246 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1250 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1252 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1255 */           switch (lexicalUnit.getLexicalUnitType()) {
/*      */             default:
/*      */               break;
/*      */             case 13:
/* 1259 */               if (lexicalUnit.getIntegerValue() != 0) {
/*      */                 break;
/*      */               }
/* 1262 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 35:
/* 1265 */               if (!lexicalUnit.getStringValue().equalsIgnoreCase("auto")) {
/*      */                 break;
/*      */               }
/* 1268 */               lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */               break;
/*      */             case 15:
/*      */             case 16:
/*      */             case 17:
/*      */             case 18:
/*      */             case 19:
/*      */             case 20:
/*      */             case 21:
/*      */             case 22:
/*      */             case 23:
/* 1279 */               lexicalUnit = lexicalUnit.getNextLexicalUnit(); break;
/*      */           } 
/* 1281 */           if (lexicalUnit != null) {
/*      */             break;
/*      */           }
/* 1284 */           return CSSLexicalUnit.createPredefinedFunction((short)38, params, prev);
/*      */         } 
/*      */         break;
/*      */       
/*      */       case 'C':
/*      */       case 'c':
/* 1290 */         if (name.equalsIgnoreCase("counter")) {
/* 1291 */           LexicalUnit lexicalUnit = params;
/* 1292 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1295 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 35:
/*      */               break; }
/* 1299 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1301 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1304 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1308 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1310 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1313 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 35:
/*      */               break; }
/* 1317 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1319 */           if (lexicalUnit != null) {
/*      */             break;
/*      */           }
/* 1322 */           return CSSLexicalUnit.createPredefinedFunction((short)25, params, prev);
/*      */         } 
/* 1324 */         if (name.equalsIgnoreCase("counters")) {
/* 1325 */           LexicalUnit lexicalUnit = params;
/* 1326 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1329 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 35:
/*      */               break; }
/* 1333 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1335 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1338 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1342 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1344 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1347 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 36:
/*      */               break; }
/* 1351 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1353 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1356 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 0:
/*      */               break; }
/* 1360 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1362 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1365 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 35:
/*      */               break; }
/* 1369 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1371 */           if (lexicalUnit != null) {
/*      */             break;
/*      */           }
/* 1374 */           return CSSLexicalUnit.createPredefinedFunction((short)26, params, prev);
/*      */         } 
/*      */         break;
/*      */       
/*      */       case 'A':
/*      */       case 'a':
/* 1380 */         if (name.equalsIgnoreCase("attr")) {
/* 1381 */           LexicalUnit lexicalUnit = params;
/* 1382 */           if (lexicalUnit == null) {
/*      */             break;
/*      */           }
/* 1385 */           switch (lexicalUnit.getLexicalUnitType()) { default:
/*      */               break;
/*      */             case 35:
/*      */               break; }
/* 1389 */            lexicalUnit = lexicalUnit.getNextLexicalUnit();
/*      */           
/* 1391 */           if (lexicalUnit != null) {
/*      */             break;
/*      */           }
/* 1394 */           return CSSLexicalUnit.createString((short)37, params.getStringValue(), prev);
/*      */         } 
/*      */         break;
/*      */     } 
/*      */     
/* 1399 */     return CSSLexicalUnit.createFunction(name, params, prev);
/*      */   }
/*      */   protected LexicalUnit hexcolor(LexicalUnit prev) {
/*      */     char bc2, bc1, gc2, gc1, rc2, rc1;
/*      */     LexicalUnit tmp;
/*      */     int b, g, r, t;
/*      */     char bc, gc, rc;
/* 1406 */     String val = this.scanner.getStringValue();
/* 1407 */     int len = val.length();
/* 1408 */     LexicalUnit params = null;
/* 1409 */     switch (len) {
/*      */       case 3:
/* 1411 */         rc = Character.toLowerCase(val.charAt(0));
/* 1412 */         gc = Character.toLowerCase(val.charAt(1));
/* 1413 */         bc = Character.toLowerCase(val.charAt(2));
/* 1414 */         if (!ScannerUtilities.isCSSHexadecimalCharacter(rc) || !ScannerUtilities.isCSSHexadecimalCharacter(gc) || !ScannerUtilities.isCSSHexadecimalCharacter(bc))
/*      */         {
/*      */           
/* 1417 */           throw createCSSParseException("rgb.color", new Object[] { val });
/*      */         }
/*      */ 
/*      */         
/* 1421 */         r = t = (rc >= '0' && rc <= '9') ? (rc - '0') : (rc - 'a' + '\n');
/* 1422 */         t <<= 4;
/* 1423 */         r |= t;
/* 1424 */         g = t = (gc >= '0' && gc <= '9') ? (gc - '0') : (gc - 'a' + '\n');
/* 1425 */         t <<= 4;
/* 1426 */         g |= t;
/* 1427 */         b = t = (bc >= '0' && bc <= '9') ? (bc - '0') : (bc - 'a' + '\n');
/* 1428 */         t <<= 4;
/* 1429 */         b |= t;
/* 1430 */         params = CSSLexicalUnit.createInteger(r, null);
/*      */         
/* 1432 */         tmp = CSSLexicalUnit.createSimple((short)0, params);
/*      */         
/* 1434 */         tmp = CSSLexicalUnit.createInteger(g, tmp);
/* 1435 */         tmp = CSSLexicalUnit.createSimple((short)0, tmp);
/*      */         
/* 1437 */         tmp = CSSLexicalUnit.createInteger(b, tmp);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1474 */         nextIgnoreSpaces();
/* 1475 */         return CSSLexicalUnit.createPredefinedFunction((short)27, params, prev);case 6: rc1 = Character.toLowerCase(val.charAt(0)); rc2 = Character.toLowerCase(val.charAt(1)); gc1 = Character.toLowerCase(val.charAt(2)); gc2 = Character.toLowerCase(val.charAt(3)); bc1 = Character.toLowerCase(val.charAt(4)); bc2 = Character.toLowerCase(val.charAt(5)); if (!ScannerUtilities.isCSSHexadecimalCharacter(rc1) || !ScannerUtilities.isCSSHexadecimalCharacter(rc2) || !ScannerUtilities.isCSSHexadecimalCharacter(gc1) || !ScannerUtilities.isCSSHexadecimalCharacter(gc2) || !ScannerUtilities.isCSSHexadecimalCharacter(bc1) || !ScannerUtilities.isCSSHexadecimalCharacter(bc2)) throw createCSSParseException("rgb.color");  r = (rc1 >= '0' && rc1 <= '9') ? (rc1 - '0') : (rc1 - 'a' + '\n'); r <<= 4; r |= ((rc2 >= '0' && rc2 <= '9') ? (rc2 - '0') : (rc2 - 'a' + '\n')); g = (gc1 >= '0' && gc1 <= '9') ? (gc1 - '0') : (gc1 - 'a' + '\n'); g <<= 4; g |= ((gc2 >= '0' && gc2 <= '9') ? (gc2 - '0') : (gc2 - 'a' + '\n')); b = (bc1 >= '0' && bc1 <= '9') ? (bc1 - '0') : (bc1 - 'a' + '\n'); b <<= 4; b |= ((bc2 >= '0' && bc2 <= '9') ? (bc2 - '0') : (bc2 - 'a' + '\n')); params = CSSLexicalUnit.createInteger(r, null); tmp = CSSLexicalUnit.createSimple((short)0, params); tmp = CSSLexicalUnit.createInteger(g, tmp); tmp = CSSLexicalUnit.createSimple((short)0, tmp); tmp = CSSLexicalUnit.createInteger(b, tmp); nextIgnoreSpaces(); return CSSLexicalUnit.createPredefinedFunction((short)27, params, prev);
/*      */     } 
/*      */     throw createCSSParseException("rgb.color", new Object[] { val });
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   protected Scanner createScanner(InputSource source) {
/* 1483 */     this.documentURI = source.getURI();
/* 1484 */     if (this.documentURI == null) {
/* 1485 */       this.documentURI = "";
/*      */     }
/*      */     
/* 1488 */     Reader r = source.getCharacterStream();
/* 1489 */     if (r != null) {
/* 1490 */       return new Scanner(r);
/*      */     }
/*      */     
/* 1493 */     InputStream is = source.getByteStream();
/* 1494 */     if (is != null) {
/* 1495 */       return new Scanner(is, source.getEncoding());
/*      */     }
/*      */     
/* 1498 */     String uri = source.getURI();
/* 1499 */     if (uri == null) {
/* 1500 */       throw new CSSException(formatMessage("empty.source", null));
/*      */     }
/*      */     
/*      */     try {
/* 1504 */       ParsedURL purl = new ParsedURL(uri);
/* 1505 */       is = purl.openStreamRaw("text/css");
/* 1506 */       return new Scanner(is, source.getEncoding());
/*      */     } catch (IOException e) {
/* 1508 */       throw new CSSException(e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int skipSpaces() {
/* 1516 */     int lex = this.scanner.getType();
/* 1517 */     while (lex == 17) {
/* 1518 */       lex = next();
/*      */     }
/* 1520 */     return lex;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int skipSpacesAndCDOCDC() {
/*      */     while (true) {
/* 1528 */       switch (this.current) {
/*      */         default:
/*      */           break;
/*      */         case 17:
/*      */         case 18:
/*      */         case 21:
/*      */         case 22:
/*      */           break;
/* 1536 */       }  this.scanner.clearBuffer();
/* 1537 */       next();
/*      */     } 
/* 1539 */     return this.current;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected float number(boolean positive) {
/*      */     try {
/* 1547 */       float sgn = positive ? 1.0F : -1.0F;
/* 1548 */       String val = this.scanner.getStringValue();
/* 1549 */       nextIgnoreSpaces();
/* 1550 */       return sgn * Float.parseFloat(val);
/*      */     } catch (NumberFormatException e) {
/* 1552 */       throw createCSSParseException("number.format");
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected LexicalUnit dimension(boolean positive, LexicalUnit prev) {
/*      */     try {
/* 1561 */       float sgn = positive ? 1.0F : -1.0F;
/* 1562 */       String val = this.scanner.getStringValue();
/*      */       int i;
/* 1564 */       for (i = 0; i < val.length(); i++)
/* 1565 */       { switch (val.charAt(i)) { default: break;
/*      */           case '.': case '0': case '1': case '2': case '3':
/*      */           case '4':
/*      */           case '5':
/*      */           case '6':
/*      */           case '7':
/*      */           case '8':
/*      */           case '9':
/* 1573 */             break; }  }  nextIgnoreSpaces();
/* 1574 */       return CSSLexicalUnit.createDimension(sgn * Float.parseFloat(val.substring(0, i)), val.substring(i), prev);
/*      */     
/*      */     }
/*      */     catch (NumberFormatException e) {
/*      */       
/* 1579 */       throw createCSSParseException("number.format");
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int next() {
/*      */     try {
/*      */       while (true) {
/* 1589 */         this.scanner.clearBuffer();
/* 1590 */         this.current = this.scanner.next();
/* 1591 */         if (this.current == 18) {
/* 1592 */           this.documentHandler.comment(this.scanner.getStringValue());
/*      */           continue;
/*      */         } 
/*      */         break;
/*      */       } 
/* 1597 */       return this.current;
/*      */     } catch (ParseException e) {
/* 1599 */       reportError(e.getMessage());
/* 1600 */       return this.current;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int nextIgnoreSpaces() {
/*      */     try {
/*      */       while (true) {
/* 1610 */         this.scanner.clearBuffer();
/* 1611 */         this.current = this.scanner.next();
/* 1612 */         switch (this.current) {
/*      */           case 18:
/* 1614 */             this.documentHandler.comment(this.scanner.getStringValue());
/*      */           default:
/*      */             break;
/*      */           case 17:
/*      */             break;
/*      */         } 
/*      */       } 
/* 1621 */       return this.current;
/*      */     } catch (ParseException e) {
/* 1623 */       this.errorHandler.error(createCSSParseException(e.getMessage()));
/* 1624 */       return this.current;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1632 */   protected void reportError(String key) throws CSSException, IOException { reportError(key, null); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1639 */   protected void reportError(String key, Object[] params) { reportError(createCSSParseException(key, params)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void reportError(CSSParseException e) {
/* 1646 */     this.errorHandler.error(e);
/*      */     
/* 1648 */     int cbraces = 1;
/*      */     while (true) {
/* 1650 */       switch (this.current) {
/*      */         case 0:
/*      */           return;
/*      */         case 2:
/*      */         case 8:
/* 1655 */           if (--cbraces == 0) {
/* 1656 */             nextIgnoreSpaces();
/*      */             return;
/*      */           } 
/*      */         case 1:
/* 1660 */           cbraces++; break;
/*      */       } 
/* 1662 */       nextIgnoreSpaces();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1670 */   protected CSSParseException createCSSParseException(String key) { return createCSSParseException(key, null); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1678 */   protected CSSParseException createCSSParseException(String key, Object[] params) { return new CSSParseException(formatMessage(key, params), this.documentURI, this.scanner.getLine(), this.scanner.getColumn()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseStyleDeclaration(String source) throws CSSException, IOException {
/* 1693 */     this.scanner = new Scanner(source);
/* 1694 */     parseStyleDeclarationInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void parseRule(String source) throws CSSException, IOException {
/* 1701 */     this.scanner = new Scanner(source);
/* 1702 */     parseRuleInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public SelectorList parseSelectors(String source) throws CSSException, IOException {
/* 1710 */     this.scanner = new Scanner(source);
/* 1711 */     return parseSelectorsInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public LexicalUnit parsePropertyValue(String source) throws CSSException, IOException {
/* 1719 */     this.scanner = new Scanner(source);
/* 1720 */     return parsePropertyValueInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean parsePriority(String source) {
/* 1728 */     this.scanner = new Scanner(source);
/* 1729 */     return parsePriorityInternal();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public SACMediaList parseMedia(String mediaText) throws CSSException, IOException {
/* 1737 */     CSSSACMediaList result = new CSSSACMediaList();
/* 1738 */     if (!"all".equalsIgnoreCase(mediaText)) {
/* 1739 */       StringTokenizer st = new StringTokenizer(mediaText, " ,");
/* 1740 */       while (st.hasMoreTokens()) {
/* 1741 */         result.append(st.nextToken());
/*      */       }
/*      */     } 
/* 1744 */     return result;
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\parser\Parser.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */