/*      */ package org.apache.batik.css.parser;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import org.apache.batik.util.io.NormalizingReader;
/*      */ import org.apache.batik.util.io.StreamNormalizingReader;
/*      */ import org.apache.batik.util.io.StringNormalizingReader;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class Scanner
/*      */ {
/*      */   protected NormalizingReader reader;
/*      */   protected int current;
/*   51 */   protected char[] buffer = new char[128];
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int position;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int type;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int start;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int end;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int blankCharacters;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Scanner(Reader r) throws ParseException {
/*      */     try {
/*   85 */       this.reader = new StreamNormalizingReader(r);
/*   86 */       this.current = nextChar();
/*      */     } catch (IOException e) {
/*   88 */       throw new ParseException(e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Scanner(InputStream is, String enc) throws ParseException {
/*      */     try {
/*   99 */       this.reader = new StreamNormalizingReader(is, enc);
/*  100 */       this.current = nextChar();
/*      */     } catch (IOException e) {
/*  102 */       throw new ParseException(e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Scanner(String s) throws ParseException {
/*      */     try {
/*  112 */       this.reader = new StringNormalizingReader(s);
/*  113 */       this.current = nextChar();
/*      */     } catch (IOException e) {
/*  115 */       throw new ParseException(e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  123 */   public int getLine() { return this.reader.getLine(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  130 */   public int getColumn() { return this.reader.getColumn(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  137 */   public char[] getBuffer() { return this.buffer; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  144 */   public int getStart() { return this.start; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  151 */   public int getEnd() { return this.end; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void clearBuffer() {
/*  158 */     if (this.position <= 0) {
/*  159 */       this.position = 0;
/*      */     } else {
/*  161 */       this.buffer[0] = this.buffer[this.position - 1];
/*  162 */       this.position = 1;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  170 */   public int getType() { return this.type; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  177 */   public String getStringValue() { return new String(this.buffer, this.start, this.end - this.start); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void scanAtRule() {
/*      */     try {
/*      */       while (true) {
/*      */         int brackets;
/*  188 */         switch (this.current) {
/*      */           case 123:
/*  190 */             brackets = 1;
/*      */             while (true) {
/*  192 */               nextChar();
/*  193 */               switch (this.current) {
/*      */                 case 125:
/*  195 */                   if (--brackets > 0)
/*      */                     continue; 
/*      */                   break;
/*      */                 case -1:
/*      */                   break;
/*      */                 case 123:
/*  201 */                   brackets++;
/*      */               } 
/*      */             }  break;
/*      */           case -1:
/*      */           case 59:
/*      */             break;
/*      */         } 
/*  208 */         nextChar();
/*      */       } 
/*  210 */       this.end = this.position;
/*      */     } catch (IOException e) {
/*  212 */       throw new ParseException(e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int next() {
/*  220 */     this.blankCharacters = 0;
/*  221 */     this.start = this.position - 1;
/*  222 */     nextToken();
/*  223 */     this.end = this.position - endGap();
/*  224 */     return this.type;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int endGap() {
/*  231 */     int result = (this.current == -1) ? 0 : 1;
/*  232 */     switch (this.type) {
/*      */       case 19:
/*      */       case 42:
/*      */       case 43:
/*      */       case 52:
/*  237 */         result++;
/*      */         break;
/*      */       case 18:
/*      */       case 35:
/*      */       case 36:
/*      */       case 37:
/*      */       case 38:
/*      */       case 39:
/*      */       case 40:
/*      */       case 41:
/*      */       case 44:
/*      */       case 45:
/*      */       case 46:
/*  250 */         result += 2;
/*      */         break;
/*      */       case 47:
/*      */       case 48:
/*      */       case 50:
/*  255 */         result += 3;
/*      */         break;
/*      */       case 49:
/*  258 */         result += 4; break;
/*      */     } 
/*  260 */     return result + this.blankCharacters;
/*      */   }
/*      */ 
/*      */   
/*      */   protected void nextToken() {
/*      */     try {
/*      */       int i;
/*      */       boolean range;
/*  268 */       switch (this.current) {
/*      */         case -1:
/*  270 */           this.type = 0;
/*      */           return;
/*      */         case 123:
/*  273 */           nextChar();
/*  274 */           this.type = 1;
/*      */           return;
/*      */         case 125:
/*  277 */           nextChar();
/*  278 */           this.type = 2;
/*      */           return;
/*      */         case 61:
/*  281 */           nextChar();
/*  282 */           this.type = 3;
/*      */           return;
/*      */         case 43:
/*  285 */           nextChar();
/*  286 */           this.type = 4;
/*      */           return;
/*      */         case 44:
/*  289 */           nextChar();
/*  290 */           this.type = 6;
/*      */           return;
/*      */         case 59:
/*  293 */           nextChar();
/*  294 */           this.type = 8;
/*      */           return;
/*      */         case 62:
/*  297 */           nextChar();
/*  298 */           this.type = 9;
/*      */           return;
/*      */         case 91:
/*  301 */           nextChar();
/*  302 */           this.type = 11;
/*      */           return;
/*      */         case 93:
/*  305 */           nextChar();
/*  306 */           this.type = 12;
/*      */           return;
/*      */         case 42:
/*  309 */           nextChar();
/*  310 */           this.type = 13;
/*      */           return;
/*      */         case 40:
/*  313 */           nextChar();
/*  314 */           this.type = 14;
/*      */           return;
/*      */         case 41:
/*  317 */           nextChar();
/*  318 */           this.type = 15;
/*      */           return;
/*      */         case 58:
/*  321 */           nextChar();
/*  322 */           this.type = 16;
/*      */           return;
/*      */         case 9:
/*      */         case 10:
/*      */         case 12:
/*      */         case 13:
/*      */         case 32:
/*      */           do {
/*  330 */             nextChar();
/*  331 */           } while (ScannerUtilities.isCSSSpace((char)this.current));
/*  332 */           this.type = 17;
/*      */           return;
/*      */         case 47:
/*  335 */           nextChar();
/*  336 */           if (this.current != 42) {
/*  337 */             this.type = 10;
/*      */             
/*      */             return;
/*      */           } 
/*  341 */           nextChar();
/*  342 */           this.start = this.position - 1;
/*      */           while (true)
/*  344 */           { if (this.current == -1 || this.current == 42)
/*      */             
/*      */             { 
/*      */               do {
/*  348 */                 nextChar();
/*  349 */               } while (this.current != -1 && this.current == 42);
/*  350 */               if (this.current == -1 || this.current == 47)
/*  351 */                 break;  continue; }  nextChar(); }  if (this.current == -1) {
/*  352 */             throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */           }
/*      */ 
/*      */           
/*  356 */           nextChar();
/*  357 */           this.type = 18;
/*      */           return;
/*      */         case 39:
/*  360 */           this.type = string1();
/*      */           return;
/*      */         case 34:
/*  363 */           this.type = string2();
/*      */           return;
/*      */         case 60:
/*  366 */           nextChar();
/*  367 */           if (this.current != 33) {
/*  368 */             throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */           }
/*      */ 
/*      */           
/*  372 */           nextChar();
/*  373 */           if (this.current == 45) {
/*  374 */             nextChar();
/*  375 */             if (this.current == 45) {
/*  376 */               nextChar();
/*  377 */               this.type = 21;
/*      */               return;
/*      */             } 
/*      */           } 
/*  381 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */ 
/*      */         
/*      */         case 45:
/*  385 */           nextChar();
/*  386 */           if (this.current != 45) {
/*  387 */             this.type = 5;
/*      */             return;
/*      */           } 
/*  390 */           nextChar();
/*  391 */           if (this.current == 62) {
/*  392 */             nextChar();
/*  393 */             this.type = 22;
/*      */             return;
/*      */           } 
/*  396 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */ 
/*      */         
/*      */         case 124:
/*  400 */           nextChar();
/*  401 */           if (this.current == 61) {
/*  402 */             nextChar();
/*  403 */             this.type = 25;
/*      */             return;
/*      */           } 
/*  406 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */ 
/*      */         
/*      */         case 126:
/*  410 */           nextChar();
/*  411 */           if (this.current == 61) {
/*  412 */             nextChar();
/*  413 */             this.type = 26;
/*      */             return;
/*      */           } 
/*  416 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */ 
/*      */         
/*      */         case 35:
/*  420 */           nextChar();
/*  421 */           if (ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*  422 */             this.start = this.position - 1;
/*      */             do {
/*  424 */               nextChar();
/*  425 */               while (this.current == 92) {
/*  426 */                 nextChar();
/*  427 */                 escape();
/*      */               } 
/*  429 */             } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */             
/*  432 */             this.type = 27;
/*      */             return;
/*      */           } 
/*  435 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */ 
/*      */         
/*      */         case 64:
/*  439 */           nextChar();
/*  440 */           switch (this.current) {
/*      */             case 67:
/*      */             case 99:
/*  443 */               this.start = this.position - 1;
/*  444 */               if (isEqualIgnoreCase(nextChar(), 'h') && isEqualIgnoreCase(nextChar(), 'a') && isEqualIgnoreCase(nextChar(), 'r') && isEqualIgnoreCase(nextChar(), 's') && isEqualIgnoreCase(nextChar(), 'e') && isEqualIgnoreCase(nextChar(), 't')) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */                 
/*  450 */                 nextChar();
/*  451 */                 this.type = 30;
/*      */                 return;
/*      */               } 
/*      */               break;
/*      */             case 70:
/*      */             case 102:
/*  457 */               this.start = this.position - 1;
/*  458 */               if (isEqualIgnoreCase(nextChar(), 'o') && isEqualIgnoreCase(nextChar(), 'n') && isEqualIgnoreCase(nextChar(), 't') && isEqualIgnoreCase(nextChar(), '-') && isEqualIgnoreCase(nextChar(), 'f') && isEqualIgnoreCase(nextChar(), 'a') && isEqualIgnoreCase(nextChar(), 'c') && isEqualIgnoreCase(nextChar(), 'e')) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */                 
/*  466 */                 nextChar();
/*  467 */                 this.type = 31;
/*      */                 return;
/*      */               } 
/*      */               break;
/*      */             case 73:
/*      */             case 105:
/*  473 */               this.start = this.position - 1;
/*  474 */               if (isEqualIgnoreCase(nextChar(), 'm') && isEqualIgnoreCase(nextChar(), 'p') && isEqualIgnoreCase(nextChar(), 'o') && isEqualIgnoreCase(nextChar(), 'r') && isEqualIgnoreCase(nextChar(), 't')) {
/*      */ 
/*      */ 
/*      */ 
/*      */                 
/*  479 */                 nextChar();
/*  480 */                 this.type = 28;
/*      */                 return;
/*      */               } 
/*      */               break;
/*      */             case 77:
/*      */             case 109:
/*  486 */               this.start = this.position - 1;
/*  487 */               if (isEqualIgnoreCase(nextChar(), 'e') && isEqualIgnoreCase(nextChar(), 'd') && isEqualIgnoreCase(nextChar(), 'i') && isEqualIgnoreCase(nextChar(), 'a')) {
/*      */ 
/*      */ 
/*      */                 
/*  491 */                 nextChar();
/*  492 */                 this.type = 32;
/*      */                 return;
/*      */               } 
/*      */               break;
/*      */             case 80:
/*      */             case 112:
/*  498 */               this.start = this.position - 1;
/*  499 */               if (isEqualIgnoreCase(nextChar(), 'a') && isEqualIgnoreCase(nextChar(), 'g') && isEqualIgnoreCase(nextChar(), 'e')) {
/*      */ 
/*      */                 
/*  502 */                 nextChar();
/*  503 */                 this.type = 33;
/*      */                 return;
/*      */               } 
/*      */               break;
/*      */             default:
/*  508 */               if (!ScannerUtilities.isCSSIdentifierStartCharacter((char)this.current))
/*      */               {
/*  510 */                 throw new ParseException("identifier.character", this.reader.getLine(), this.reader.getColumn());
/*      */               }
/*      */ 
/*      */               
/*  514 */               this.start = this.position - 1; break;
/*      */           } 
/*      */           do {
/*  517 */             nextChar();
/*  518 */             while (this.current == 92) {
/*  519 */               nextChar();
/*  520 */               escape();
/*      */             } 
/*  522 */           } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */           
/*  524 */           this.type = 29;
/*      */           return;
/*      */         case 33:
/*      */           do {
/*  528 */             nextChar();
/*  529 */           } while (this.current != -1 && ScannerUtilities.isCSSSpace((char)this.current));
/*      */           
/*  531 */           if (isEqualIgnoreCase(this.current, 'i') && isEqualIgnoreCase(nextChar(), 'm') && isEqualIgnoreCase(nextChar(), 'p') && isEqualIgnoreCase(nextChar(), 'o') && isEqualIgnoreCase(nextChar(), 'r') && isEqualIgnoreCase(nextChar(), 't') && isEqualIgnoreCase(nextChar(), 'a') && isEqualIgnoreCase(nextChar(), 'n') && isEqualIgnoreCase(nextChar(), 't')) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/*  540 */             nextChar();
/*  541 */             this.type = 23;
/*      */             return;
/*      */           } 
/*  544 */           if (this.current == -1) {
/*  545 */             throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */           }
/*      */ 
/*      */           
/*  549 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */         case 48: case 49: case 50: case 51: case 52: case 53:
/*      */         case 54:
/*      */         case 55:
/*      */         case 56:
/*      */         case 57:
/*  555 */           this.type = number();
/*      */           return;
/*      */         case 46:
/*  558 */           switch (nextChar()) { case 48: case 49: case 50: case 51: case 52: case 53: case 54: case 55:
/*      */             case 56:
/*      */             case 57:
/*  561 */               this.type = dotNumber();
/*      */               return; }
/*      */           
/*  564 */           this.type = 7;
/*      */           return;
/*      */         
/*      */         case 85:
/*      */         case 117:
/*  569 */           nextChar();
/*  570 */           switch (this.current) {
/*      */             case 43:
/*  572 */               range = false;
/*  573 */               for (i = 0; i < 6; i++) {
/*  574 */                 nextChar();
/*  575 */                 switch (this.current) {
/*      */                   case 63:
/*  577 */                     range = true;
/*      */                     break;
/*      */                   default:
/*  580 */                     if (range && !ScannerUtilities.isCSSHexadecimalCharacter((char)this.current))
/*      */                     {
/*      */                       
/*  583 */                       throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                     }
/*      */                     break;
/*      */                 } 
/*      */               
/*      */               } 
/*  589 */               nextChar();
/*  590 */               if (range) {
/*  591 */                 this.type = 53;
/*      */                 return;
/*      */               } 
/*  594 */               if (this.current == 45) {
/*  595 */                 nextChar();
/*  596 */                 if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current))
/*      */                 {
/*  598 */                   throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                 }
/*      */ 
/*      */                 
/*  602 */                 nextChar();
/*  603 */                 if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/*      */                   
/*  605 */                   this.type = 53;
/*      */                   return;
/*      */                 } 
/*  608 */                 nextChar();
/*  609 */                 if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/*      */                   
/*  611 */                   this.type = 53;
/*      */                   return;
/*      */                 } 
/*  614 */                 nextChar();
/*  615 */                 if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/*      */                   
/*  617 */                   this.type = 53;
/*      */                   return;
/*      */                 } 
/*  620 */                 nextChar();
/*  621 */                 if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/*      */                   
/*  623 */                   this.type = 53;
/*      */                   return;
/*      */                 } 
/*  626 */                 nextChar();
/*  627 */                 if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/*      */                   
/*  629 */                   this.type = 53;
/*      */                   return;
/*      */                 } 
/*  632 */                 nextChar();
/*  633 */                 this.type = 53;
/*      */                 return;
/*      */               } 
/*      */             case 82:
/*      */             case 114:
/*  638 */               nextChar();
/*  639 */               switch (this.current) {
/*      */                 case 76:
/*      */                 case 108:
/*  642 */                   nextChar();
/*  643 */                   switch (this.current) {
/*      */                     case 40:
/*      */                       do {
/*  646 */                         nextChar();
/*  647 */                       } while (this.current != -1 && ScannerUtilities.isCSSSpace((char)this.current));
/*      */ 
/*      */                       
/*  650 */                       switch (this.current) {
/*      */                         case 39:
/*  652 */                           string1();
/*  653 */                           this.blankCharacters += 2;
/*  654 */                           while (this.current != -1 && ScannerUtilities.isCSSSpace((char)this.current)) {
/*      */ 
/*      */                             
/*  657 */                             this.blankCharacters++;
/*  658 */                             nextChar();
/*      */                           } 
/*  660 */                           if (this.current == -1) {
/*  661 */                             throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */                           }
/*      */ 
/*      */ 
/*      */                           
/*  666 */                           if (this.current != 41) {
/*  667 */                             throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                           }
/*      */ 
/*      */ 
/*      */                           
/*  672 */                           nextChar();
/*  673 */                           this.type = 51;
/*      */                           return;
/*      */                         case 34:
/*  676 */                           string2();
/*  677 */                           this.blankCharacters += 2;
/*  678 */                           while (this.current != -1 && ScannerUtilities.isCSSSpace((char)this.current)) {
/*      */ 
/*      */                             
/*  681 */                             this.blankCharacters++;
/*  682 */                             nextChar();
/*      */                           } 
/*  684 */                           if (this.current == -1) {
/*  685 */                             throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */                           }
/*      */ 
/*      */ 
/*      */                           
/*  690 */                           if (this.current != 41) {
/*  691 */                             throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                           }
/*      */ 
/*      */ 
/*      */                           
/*  696 */                           nextChar();
/*  697 */                           this.type = 51;
/*      */                           return;
/*      */                         case 41:
/*  700 */                           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                       } 
/*      */ 
/*      */                       
/*  704 */                       if (!ScannerUtilities.isCSSURICharacter((char)this.current))
/*      */                       {
/*  706 */                         throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                       }
/*      */ 
/*      */ 
/*      */                       
/*  711 */                       this.start = this.position - 1;
/*      */                       do {
/*  713 */                         nextChar();
/*  714 */                       } while (this.current != -1 && ScannerUtilities.isCSSURICharacter((char)this.current));
/*      */ 
/*      */                       
/*  717 */                       this.blankCharacters++;
/*  718 */                       while (this.current != -1 && ScannerUtilities.isCSSSpace((char)this.current)) {
/*      */ 
/*      */                         
/*  721 */                         this.blankCharacters++;
/*  722 */                         nextChar();
/*      */                       } 
/*  724 */                       if (this.current == -1) {
/*  725 */                         throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */                       }
/*      */ 
/*      */ 
/*      */                       
/*  730 */                       if (this.current != 41) {
/*  731 */                         throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */                       }
/*      */ 
/*      */ 
/*      */                       
/*  736 */                       nextChar();
/*  737 */                       this.type = 51; return;
/*      */                   } 
/*      */                   break;
/*      */               } 
/*      */               break;
/*      */           } 
/*  743 */           while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */           {
/*  745 */             nextChar();
/*      */           }
/*  747 */           if (this.current == 40) {
/*  748 */             nextChar();
/*  749 */             this.type = 52;
/*      */             return;
/*      */           } 
/*  752 */           this.type = 20;
/*      */           return;
/*      */       } 
/*  755 */       if (this.current == 92) {
/*      */         do {
/*  757 */           nextChar();
/*  758 */           escape();
/*  759 */         } while (this.current == 92);
/*  760 */       } else if (!ScannerUtilities.isCSSIdentifierStartCharacter((char)this.current)) {
/*      */         
/*  762 */         nextChar();
/*  763 */         throw new ParseException("identifier.character", this.reader.getLine(), this.reader.getColumn());
/*      */       } 
/*      */ 
/*      */ 
/*      */       
/*  768 */       while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */         
/*  770 */         nextChar();
/*  771 */         while (this.current == 92) {
/*  772 */           nextChar();
/*  773 */           escape();
/*      */         } 
/*      */       } 
/*  776 */       if (this.current == 40) {
/*  777 */         nextChar();
/*  778 */         this.type = 52;
/*      */         return;
/*      */       } 
/*  781 */       this.type = 20;
/*      */       
/*      */       return;
/*      */     } catch (IOException e) {
/*  785 */       throw new ParseException(e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int string1() {
/*  793 */     this.start = this.position;
/*      */     while (true) {
/*  795 */       switch (nextChar()) {
/*      */         case -1:
/*  797 */           throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */         
/*      */         case 39:
/*      */           break;
/*      */         
/*      */         case 34:
/*      */           continue;
/*      */         case 92:
/*  805 */           switch (nextChar()) {
/*      */             case 10:
/*      */             case 12:
/*      */               continue;
/*      */           } 
/*  810 */           escape();
/*      */           continue;
/*      */       } 
/*      */       
/*  814 */       if (!ScannerUtilities.isCSSStringCharacter((char)this.current)) {
/*  815 */         throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  821 */     nextChar();
/*  822 */     return 19;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int string2() {
/*  829 */     this.start = this.position;
/*      */     while (true) {
/*  831 */       switch (nextChar()) {
/*      */         case -1:
/*  833 */           throw new ParseException("eof", this.reader.getLine(), this.reader.getColumn());
/*      */         
/*      */         case 39:
/*      */           continue;
/*      */         
/*      */         case 34:
/*      */           break;
/*      */         case 92:
/*  841 */           switch (nextChar()) {
/*      */             case 10:
/*      */             case 12:
/*      */               continue;
/*      */           } 
/*  846 */           escape();
/*      */           continue;
/*      */       } 
/*      */       
/*  850 */       if (!ScannerUtilities.isCSSStringCharacter((char)this.current)) {
/*  851 */         throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  857 */     nextChar();
/*  858 */     return 19;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int number() {
/*      */     while (true)
/*  866 */     { switch (nextChar())
/*      */       { case 46:
/*  868 */           switch (nextChar()) { case 48: case 49: case 50: case 51: case 52: case 53: case 54: case 55:
/*      */             case 56:
/*      */             case 57:
/*  871 */               return dotNumber(); }
/*      */           
/*  873 */           throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */         case 48: case 49: case 50:
/*      */         case 51:
/*      */         case 52:
/*      */         case 53:
/*      */         case 54:
/*      */         case 55:
/*      */         case 56:
/*      */         case 57:
/*  882 */           break; }  }  return numberUnit(true);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int dotNumber() {
/*      */     while (true)
/*  890 */     { switch (nextChar()) { case 48: case 49: case 50: case 51:
/*      */         case 52:
/*      */         case 53:
/*      */         case 54:
/*      */         case 55:
/*      */         case 56:
/*      */         case 57:
/*  897 */           break; }  }  return numberUnit(false);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int numberUnit(boolean integer) throws IOException {
/*  904 */     switch (this.current) {
/*      */       case 37:
/*  906 */         nextChar();
/*  907 */         return 42;
/*      */       case 67:
/*      */       case 99:
/*  910 */         switch (nextChar()) {
/*      */           case 77:
/*      */           case 109:
/*  913 */             nextChar();
/*  914 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/*  917 */                 nextChar();
/*  918 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/*  921 */               return 34;
/*      */             } 
/*  923 */             return 37;
/*      */         } 
/*  925 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/*  927 */           nextChar();
/*      */         }
/*  929 */         return 34;
/*      */       
/*      */       case 68:
/*      */       case 100:
/*  933 */         switch (nextChar()) {
/*      */           case 69:
/*      */           case 101:
/*  936 */             switch (nextChar()) {
/*      */               case 71:
/*      */               case 103:
/*  939 */                 nextChar();
/*  940 */                 if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */                   
/*      */                   do {
/*  943 */                     nextChar();
/*  944 */                   } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */                   
/*  947 */                   return 34;
/*      */                 } 
/*  949 */                 return 47;
/*      */             }  break;
/*      */         } 
/*  952 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/*  954 */           nextChar();
/*      */         }
/*  956 */         return 34;
/*      */       
/*      */       case 69:
/*      */       case 101:
/*  960 */         switch (nextChar()) {
/*      */           case 77:
/*      */           case 109:
/*  963 */             nextChar();
/*  964 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/*  967 */                 nextChar();
/*  968 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/*  971 */               return 34;
/*      */             } 
/*  973 */             return 36;
/*      */           case 88:
/*      */           case 120:
/*  976 */             nextChar();
/*  977 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/*  980 */                 nextChar();
/*  981 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/*  984 */               return 34;
/*      */             } 
/*  986 */             return 35;
/*      */         } 
/*  988 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/*  990 */           nextChar();
/*      */         }
/*  992 */         return 34;
/*      */       
/*      */       case 71:
/*      */       case 103:
/*  996 */         switch (nextChar()) {
/*      */           case 82:
/*      */           case 114:
/*  999 */             switch (nextChar()) {
/*      */               case 65:
/*      */               case 97:
/* 1002 */                 switch (nextChar()) {
/*      */                   case 68:
/*      */                   case 100:
/* 1005 */                     nextChar();
/* 1006 */                     if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */ 
/*      */                       
/*      */                       do {
/* 1010 */                         nextChar();
/* 1011 */                       } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */                       
/* 1014 */                       return 34;
/*      */                     } 
/* 1016 */                     return 49;
/*      */                 }  break;
/*      */             }  break;
/*      */         } 
/* 1020 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1022 */           nextChar();
/*      */         }
/* 1024 */         return 34;
/*      */       
/*      */       case 72:
/*      */       case 104:
/* 1028 */         nextChar();
/* 1029 */         switch (this.current) {
/*      */           case 90:
/*      */           case 122:
/* 1032 */             nextChar();
/* 1033 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1036 */                 nextChar();
/* 1037 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1040 */               return 34;
/*      */             } 
/* 1042 */             return 41;
/*      */         } 
/* 1044 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1046 */           nextChar();
/*      */         }
/* 1048 */         return 34;
/*      */       
/*      */       case 73:
/*      */       case 105:
/* 1052 */         switch (nextChar()) {
/*      */           case 78:
/*      */           case 110:
/* 1055 */             nextChar();
/* 1056 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1059 */                 nextChar();
/* 1060 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1063 */               return 34;
/*      */             } 
/* 1065 */             return 39;
/*      */         } 
/* 1067 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1069 */           nextChar();
/*      */         }
/* 1071 */         return 34;
/*      */       
/*      */       case 75:
/*      */       case 107:
/* 1075 */         switch (nextChar()) {
/*      */           case 72:
/*      */           case 104:
/* 1078 */             switch (nextChar()) {
/*      */               case 90:
/*      */               case 122:
/* 1081 */                 nextChar();
/* 1082 */                 if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */                   
/*      */                   do {
/* 1085 */                     nextChar();
/* 1086 */                   } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */                   
/* 1089 */                   return 34;
/*      */                 } 
/* 1091 */                 return 50;
/*      */             }  break;
/*      */         } 
/* 1094 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1096 */           nextChar();
/*      */         }
/* 1098 */         return 34;
/*      */       
/*      */       case 77:
/*      */       case 109:
/* 1102 */         switch (nextChar()) {
/*      */           case 77:
/*      */           case 109:
/* 1105 */             nextChar();
/* 1106 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1109 */                 nextChar();
/* 1110 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1113 */               return 34;
/*      */             } 
/* 1115 */             return 38;
/*      */           case 83:
/*      */           case 115:
/* 1118 */             nextChar();
/* 1119 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1122 */                 nextChar();
/* 1123 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1126 */               return 34;
/*      */             } 
/* 1128 */             return 40;
/*      */         } 
/* 1130 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1132 */           nextChar();
/*      */         }
/* 1134 */         return 34;
/*      */       
/*      */       case 80:
/*      */       case 112:
/* 1138 */         switch (nextChar()) {
/*      */           case 67:
/*      */           case 99:
/* 1141 */             nextChar();
/* 1142 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1145 */                 nextChar();
/* 1146 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1149 */               return 34;
/*      */             } 
/* 1151 */             return 44;
/*      */           case 84:
/*      */           case 116:
/* 1154 */             nextChar();
/* 1155 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1158 */                 nextChar();
/* 1159 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1162 */               return 34;
/*      */             } 
/* 1164 */             return 45;
/*      */           case 88:
/*      */           case 120:
/* 1167 */             nextChar();
/* 1168 */             if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */               
/*      */               do {
/* 1171 */                 nextChar();
/* 1172 */               } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */               
/* 1175 */               return 34;
/*      */             } 
/* 1177 */             return 46;
/*      */         } 
/* 1179 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1181 */           nextChar();
/*      */         }
/* 1183 */         return 34;
/*      */       
/*      */       case 82:
/*      */       case 114:
/* 1187 */         switch (nextChar()) {
/*      */           case 65:
/*      */           case 97:
/* 1190 */             switch (nextChar()) {
/*      */               case 68:
/*      */               case 100:
/* 1193 */                 nextChar();
/* 1194 */                 if (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current)) {
/*      */                   
/*      */                   do {
/* 1197 */                     nextChar();
/* 1198 */                   } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */ 
/*      */                   
/* 1201 */                   return 34;
/*      */                 } 
/* 1203 */                 return 48;
/*      */             }  break;
/*      */         } 
/* 1206 */         while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current))
/*      */         {
/* 1208 */           nextChar();
/*      */         }
/* 1210 */         return 34;
/*      */       
/*      */       case 83:
/*      */       case 115:
/* 1214 */         nextChar();
/* 1215 */         return 43;
/*      */     } 
/* 1217 */     if (this.current != -1 && ScannerUtilities.isCSSIdentifierStartCharacter((char)this.current)) {
/*      */ 
/*      */       
/*      */       do {
/* 1221 */         nextChar();
/* 1222 */       } while (this.current != -1 && ScannerUtilities.isCSSNameCharacter((char)this.current));
/*      */       
/* 1224 */       return 34;
/*      */     } 
/* 1226 */     return integer ? 24 : 54;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void escape() {
/* 1234 */     if (ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/* 1235 */       nextChar();
/* 1236 */       if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/* 1237 */         if (ScannerUtilities.isCSSSpace((char)this.current)) {
/* 1238 */           nextChar();
/*      */         }
/*      */         return;
/*      */       } 
/* 1242 */       nextChar();
/* 1243 */       if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/* 1244 */         if (ScannerUtilities.isCSSSpace((char)this.current)) {
/* 1245 */           nextChar();
/*      */         }
/*      */         return;
/*      */       } 
/* 1249 */       nextChar();
/* 1250 */       if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/* 1251 */         if (ScannerUtilities.isCSSSpace((char)this.current)) {
/* 1252 */           nextChar();
/*      */         }
/*      */         return;
/*      */       } 
/* 1256 */       nextChar();
/* 1257 */       if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/* 1258 */         if (ScannerUtilities.isCSSSpace((char)this.current)) {
/* 1259 */           nextChar();
/*      */         }
/*      */         return;
/*      */       } 
/* 1263 */       nextChar();
/* 1264 */       if (!ScannerUtilities.isCSSHexadecimalCharacter((char)this.current)) {
/* 1265 */         if (ScannerUtilities.isCSSSpace((char)this.current)) {
/* 1266 */           nextChar();
/*      */         }
/*      */         return;
/*      */       } 
/*      */     } 
/* 1271 */     if ((this.current >= 32 && this.current <= 126) || this.current >= 128) {
/* 1272 */       nextChar();
/*      */       return;
/*      */     } 
/* 1275 */     throw new ParseException("character", this.reader.getLine(), this.reader.getColumn());
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1284 */   protected static boolean isEqualIgnoreCase(int i, char c) { return (i == -1) ? false : ((Character.toLowerCase((char)i) == c)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int nextChar() {
/* 1292 */     this.current = this.reader.read();
/*      */     
/* 1294 */     if (this.current == -1) {
/* 1295 */       return this.current;
/*      */     }
/*      */     
/* 1298 */     if (this.position == this.buffer.length) {
/*      */       
/* 1300 */       char[] t = new char[1 + this.position + this.position / 2];
/* 1301 */       System.arraycopy(this.buffer, 0, t, 0, this.position);
/* 1302 */       this.buffer = t;
/*      */     } 
/*      */     
/* 1305 */     this.buffer[this.position++] = (char)this.current; return (char)this.current;
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-css.jar!\org\apache\batik\css\parser\Scanner.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */